@@ -38,6 +38,7 @@
 #include <kactioncollection.h>
 #include <kapplication.h>
 #include <kmenu.h>
+#include <kmessagebox.h>
 #include <kmimetype.h>
 #include <krun.h>
 #include <kservice.h>
@@ -45,12 +46,17 @@
 #include <kstandardaction.h>
 #include <kurl.h>
 #include <kwindowsystem.h>
+#include <kdebug.h>
 
 // Local includes
 
+#include "albummanager.h"
+#include "albumdb.h"
 #include "advancedrenamedialog.h"
+#include "advancedrenameprocessdialog.h"
 #include "albumsettings.h"
 #include "contextmenuhelper.h"
+#include "databaseaccess.h"
 #include "ddragobjects.h"
 #include "digikamapp.h"
 #include "digikamimagedelegate.h"
@@ -68,20 +74,21 @@
 namespace Digikam
 {
 
-DigikamImageView::DigikamImageView(QWidget *parent)
-                : ImageCategorizedView(parent), d(new DigikamImageViewPriv(this))
+DigikamImageView::DigikamImageView(QWidget* parent)
+    : ImageCategorizedView(parent), d(new DigikamImageViewPriv(this))
 {
     installDefaultModels();
 
     setItemDelegate(new DigikamImageDelegate(this));
     setSpacing(10);
 
-    AlbumSettings *settings = AlbumSettings::instance();
+    AlbumSettings* settings = AlbumSettings::instance();
 
     imageFilterModel()->setCategorizationMode(ImageSortSettings::CategoryByAlbum);
 
     imageAlbumModel()->setThumbnailLoadThread(ThumbnailLoadThread::defaultIconViewThread());
     setThumbnailSize((ThumbnailSize::Size)settings->getDefaultIconSize());
+    imageAlbumModel()->setPreloadThumbnails(true);
 
     imageModel()->setDragDropHandler(new ImageDragDropHandler(imageModel()));
     setDragEnabled(true);
@@ -102,10 +109,10 @@ DigikamImageView::DigikamImageView(QWidget *parent)
     d->updateOverlays();
 
     // rating overlay
-    ImageRatingOverlay *ratingOverlay = new ImageRatingOverlay(this);
+    ImageRatingOverlay* ratingOverlay = new ImageRatingOverlay(this);
     addOverlay(ratingOverlay);
 
-    connect(ratingOverlay, SIGNAL(ratingEdited(const QModelIndex &, int)),
+    connect(ratingOverlay, SIGNAL(ratingEdited(const QModelIndex&, int)),
             this, SLOT(assignRating(const QModelIndex&, int)));
 
     d->utilities = new ImageViewUtilities(this);
@@ -130,11 +137,17 @@ DigikamImageView::~DigikamImageView()
     delete d;
 }
 
-ImageViewUtilities *DigikamImageView::utilities() const
+ImageViewUtilities* DigikamImageView::utilities() const
 {
     return d->utilities;
 }
 
+void DigikamImageView::setThumbnailSize(const ThumbnailSize& size)
+{
+    imageThumbnailModel()->setPreloadThumbnailSize(size);
+    ImageCategorizedView::setThumbnailSize(size);
+}
+
 void DigikamImageView::slotSetupChanged()
 {
     setToolTipEnabled(AlbumSettings::instance()->showToolTipsIsValid());
@@ -148,12 +161,18 @@ void DigikamImageView::slotSetupChanged()
 void DigikamImageView::activated(const ImageInfo& info)
 {
     if (info.isNull())
+    {
         return;
+    }
 
     if (AlbumSettings::instance()->getItemLeftClickAction() == AlbumSettings::ShowPreview)
+    {
         emit previewRequested(info);
+    }
     else
+    {
         openInEditor(info);
+    }
 }
 
 void DigikamImageView::openInEditor(const ImageInfo& info)
@@ -164,8 +183,11 @@ void DigikamImageView::openInEditor(const ImageInfo& info)
 void DigikamImageView::openCurrentInEditor()
 {
     ImageInfo info = currentInfo();
+
     if (!info.isNull())
+    {
         d->utilities->openInEditor(info, imageInfos(), currentAlbum());
+    }
 }
 
 void DigikamImageView::showContextMenuOnInfo(QContextMenuEvent* event, const ImageInfo& info)
@@ -179,7 +201,7 @@ void DigikamImageView::showContextMenuOnInfo(QContextMenuEvent* event, const Ima
 
     // Temporary actions --------------------------------------
 
-    QAction  *viewAction = new QAction(SmallIcon("viewimage"), i18nc("View the selected image", "View"),  this);
+    QAction*  viewAction = new QAction(SmallIcon("viewimage"), i18nc("View the selected image", "View"),  this);
     viewAction->setEnabled(selectedImageIDs.count() == 1);
 
     // --------------------------------------------------------
@@ -193,25 +215,25 @@ void DigikamImageView::showContextMenuOnInfo(QContextMenuEvent* event, const Ima
     cmhelper.addServicesMenu(selectedUrls());
     cmhelper.addGotoMenu(selectedImageIDs);
     cmhelper.addKipiActions(selectedImageIDs);
-    popmenu.addSeparator();
+    cmhelper.addSeparator();
     // --------------------------------------------------------
     cmhelper.addAction("image_find_similar");
-    cmhelper.addActionLightTable();
+    cmhelper.addStandardActionLightTable();
     cmhelper.addQueueManagerMenu();
-    popmenu.addSeparator();
+    cmhelper.addSeparator();
     // --------------------------------------------------------
     cmhelper.addAction("image_rename");
     cmhelper.addAction("cut_album_selection");
     cmhelper.addAction("copy_album_selection");
     cmhelper.addAction("paste_album_selection");
-    cmhelper.addActionItemDelete(this, SLOT(deleteSelected()), selectedImageIDs.count());
-    popmenu.addSeparator();
+    cmhelper.addStandardActionItemDelete(this, SLOT(deleteSelected()), selectedImageIDs.count());
+    cmhelper.addSeparator();
     // --------------------------------------------------------
-    cmhelper.addActionThumbnail(selectedImageIDs, currentAlbum());
+    cmhelper.addStandardActionThumbnail(selectedImageIDs, currentAlbum());
     // --------------------------------------------------------
     cmhelper.addAssignTagsMenu(selectedImageIDs);
     cmhelper.addRemoveTagsMenu(selectedImageIDs);
-    popmenu.addSeparator();
+    cmhelper.addSeparator();
     // --------------------------------------------------------
     cmhelper.addRatingMenu();
 
@@ -243,34 +265,36 @@ void DigikamImageView::showContextMenuOnInfo(QContextMenuEvent* event, const Ima
 
     // --------------------------------------------------------
 
-    QAction *choice = cmhelper.exec(event->globalPos());
-    if (choice)
+    QAction* choice = cmhelper.exec(event->globalPos());
+
+    if (choice && (choice == viewAction))
     {
-        if (choice == viewAction)
-            emit previewRequested(info);
+        emit previewRequested(info);
     }
 }
 
 void DigikamImageView::showContextMenu(QContextMenuEvent* event)
 {
-    Album *album = currentAlbum();
+    Album* album = currentAlbum();
 
     if (!album ||
-         album->isRoot() ||
+        album->isRoot() ||
         (album->type() != Album::PHYSICAL && album->type() != Album::TAG) )
     {
         return;
     }
 
     KMenu popmenu(this);
-    KAction *paste        = KStandardAction::paste(this, SLOT(paste()), 0);
-    const QMimeData *data = kapp->clipboard()->mimeData(QClipboard::Clipboard);
+    KAction* paste        = KStandardAction::paste(this, SLOT(paste()), 0);
+    const QMimeData* data = kapp->clipboard()->mimeData(QClipboard::Clipboard);
 
     /**
     * @todo
     */
-    if(!data || !KUrl::List::canDecode(data))
+    if (!data || !KUrl::List::canDecode(data))
+    {
         paste->setEnabled(false);
+    }
 
     popmenu.addAction(paste);
     popmenu.exec(event->globalPos());
@@ -293,6 +317,7 @@ void DigikamImageView::insertSelectedToLightTable(bool addTo)
 void DigikamImageView::insertSelectedToCurrentQueue()
 {
     ImageInfoList imageInfoList = selectedImageInfos();
+
     if (!imageInfoList.isEmpty())
     {
         d->utilities->insertToQueueManager(imageInfoList, imageInfoList.first(), false);
@@ -302,6 +327,7 @@ void DigikamImageView::insertSelectedToCurrentQueue()
 void DigikamImageView::insertSelectedToNewQueue()
 {
     ImageInfoList imageInfoList = selectedImageInfos();
+
     if (!imageInfoList.isEmpty())
     {
         d->utilities->insertToQueueManager(imageInfoList, imageInfoList.first(), true);
@@ -311,6 +337,7 @@ void DigikamImageView::insertSelectedToNewQueue()
 void DigikamImageView::insertSelectedToExistingQueue(int queueid)
 {
     ImageInfoList imageInfoList = selectedImageInfos();
+
     if (!imageInfoList.isEmpty())
     {
         d->utilities->insertSilentToQueueManager(imageInfoList, imageInfoList.first(), queueid);
@@ -320,8 +347,11 @@ void DigikamImageView::insertSelectedToExistingQueue(int queueid)
 void DigikamImageView::deleteSelected(bool permanently)
 {
     ImageInfoList imageInfoList = selectedImageInfos();
+
     if (d->utilities->deleteImages(imageInfoList, permanently))
+    {
         awayFromSelection();
+    }
 }
 
 void DigikamImageView::deleteSelectedDirectly(bool permanently)
@@ -346,7 +376,7 @@ void DigikamImageView::assignRatingToSelected(int rating)
     MetadataManager::instance()->assignRating(selectedImageInfos(), rating);
 }
 
-void DigikamImageView::assignRating(const QModelIndex &index, int rating)
+void DigikamImageView::assignRating(const QModelIndex& index, int rating)
 {
     MetadataManager::instance()->assignRating(QList<ImageInfo>() << imageFilterModel()->imageInfo(index), rating);
 }
@@ -368,49 +398,40 @@ void DigikamImageView::setExifOrientationOfSelected(int orientation)
 
 void DigikamImageView::rename()
 {
-    if (!d->renameThread)
-    {
-        d->renameThread = new RenameThread(this);
-
-        connect(d->renameThread, SIGNAL(renameFile(const KUrl&, const QString&)),
-                d->utilities, SLOT(rename(const KUrl&, const QString&)));
-
-        connect(d->utilities, SIGNAL(imageRenameSucceeded(const KUrl&)),
-                d->renameThread, SLOT(slotSuccess(const KUrl&)));
-
-        connect(d->utilities, SIGNAL(imageRenameFailed(const KUrl&)),
-                d->renameThread, SLOT(slotFailed(const KUrl&)));
-
-        connect(d->utilities, SIGNAL(renamingAborted()),
-                d->renameThread, SLOT(cancel()));
-    }
-
     KUrl::List urls = selectedUrls();
+    NewNamesList newNamesList;
 
     QPointer<AdvancedRenameDialog> dlg = new AdvancedRenameDialog(this);
     dlg->slotAddImages(urls);
 
     if (dlg->exec() == KDialog::Accepted)
     {
-        d->renameThread->addNewNames(dlg->newNames());
-        if (!d->renameThread->isRunning())
-        {
-            d->renameThread->start();
-        }
+        newNamesList = dlg->newNames();
     }
+
     delete dlg;
+
+    if (!newNamesList.isEmpty())
+    {
+        QPointer<AdvancedRenameProcessDialog> dlg = new AdvancedRenameProcessDialog(newNamesList);
+        dlg->exec();
+        delete dlg;
+    }
 }
 
 void DigikamImageView::slotRotateLeft()
 {
     KActionMenu* action = dynamic_cast<KActionMenu*>(ContextMenuHelper::kipiRotateAction());
+
     if (action)
     {
         QList<QAction*> list = action->menu()->actions();
         foreach(QAction* ac, list)
         {
             if (ac->objectName() == QString("rotate_ccw"))
+            {
                 ac->trigger();
+            }
         }
     }
 }
@@ -418,13 +439,16 @@ void DigikamImageView::slotRotateLeft()
 void DigikamImageView::slotRotateRight()
 {
     KActionMenu* action = dynamic_cast<KActionMenu*>(ContextMenuHelper::kipiRotateAction());
+
     if (action)
     {
         QList<QAction*> list = action->menu()->actions();
         foreach(QAction* ac, list)
         {
             if (ac->objectName() == QString("rotate_cw"))
+            {
                 ac->trigger();
+            }
         }
     }
 }
