@@ -37,6 +37,7 @@
 #include <QFileInfo>
 #include <QStringList>
 #include <QSet>
+#include <QTime>
 
 // KDE includes
 
@@ -68,10 +69,10 @@ class NewlyAppearedFile
 public:
 
     NewlyAppearedFile() : albumId(0) {}
-    NewlyAppearedFile(int albumId, const QString &fileName)
+    NewlyAppearedFile(int albumId, const QString& fileName)
         : albumId(albumId), fileName(fileName) {}
 
-    bool operator==(const NewlyAppearedFile &other) const
+    bool operator==(const NewlyAppearedFile& other) const
     {
         return albumId == other.albumId && fileName == other.fileName;
     }
@@ -80,7 +81,7 @@ public:
     QString fileName;
 };
 
-inline uint qHash(const NewlyAppearedFile &file)
+inline uint qHash(const NewlyAppearedFile& file)
 {
     return ::qHash(file.albumId) ^ ::qHash(file.fileName);
 }
@@ -90,11 +91,11 @@ class CollectionScannerPriv
 
 public:
 
-    CollectionScannerPriv()
+    CollectionScannerPriv() :
+        wantSignals(false),
+        needTotalFiles(false),
+        observer(0)
     {
-        wantSignals    = false;
-        needTotalFiles = false;
-        observer       = 0;
     }
 
     QSet<QString>     nameFilters;
@@ -108,28 +109,37 @@ public:
     QDateTime         removedItemsTime;
 
     QHash<CollectionScannerHints::DstPath, CollectionScannerHints::Album>
-                      albumHints;
+    albumHints;
     QHash<NewlyAppearedFile, qlonglong>
-                      itemHints;
+    itemHints;
     QHash<int,int>    establishedSourceAlbums;
     QSet<int>         modifiedItemHints;
     QSet<int>         rescanItemHints;
 
-    CollectionScannerObserver *observer;
+    CollectionScannerObserver* observer;
 
-    void resetRemovedItemsTime() { removedItemsTime = QDateTime(); }
-    void removedItems() { removedItemsTime = QDateTime::currentDateTime(); }
+    void resetRemovedItemsTime()
+    {
+        removedItemsTime = QDateTime();
+    }
+    void removedItems()
+    {
+        removedItemsTime = QDateTime::currentDateTime();
+    }
 
     inline bool checkObserver()
     {
         if (observer)
+        {
             return observer->continueQuery();
+        }
+
         return true;
     }
 };
 
 CollectionScanner::CollectionScanner()
-                 : d(new CollectionScannerPriv)
+    : d(new CollectionScannerPriv)
 {
 }
 
@@ -151,8 +161,10 @@ void CollectionScanner::setNeedFileCount(bool on)
 void CollectionScanner::recordHints(const QList<AlbumCopyMoveHint>& hints)
 {
     foreach(const AlbumCopyMoveHint& hint, hints)
+    {
         // automagic casting to src and dst
         d->albumHints[hint] = hint;
+    }
 }
 
 void CollectionScanner::recordHints(const QList<ItemCopyMoveHint>& hints)
@@ -161,8 +173,11 @@ void CollectionScanner::recordHints(const QList<ItemCopyMoveHint>& hints)
     {
         QList<qlonglong> ids = hint.srcIds();
         QStringList dstNames = hint.dstNames();
-        for(int i=0;i<ids.size();++i)
+
+        for (int i=0; i<ids.size(); ++i)
+        {
             d->itemHints[NewlyAppearedFile(hint.albumIdDst(), dstNames[i])] = ids[i];
+        }
     }
 }
 
@@ -171,12 +186,17 @@ void CollectionScanner::recordHints(const QList<ItemChangeHint>& hints)
     foreach(const ItemChangeHint& hint, hints)
     {
         QList<qlonglong> ids = hint.ids();
-        for(int i=0;i<ids.size();++i)
+
+        for (int i=0; i<ids.size(); ++i)
         {
             if (hint.isModified())
+            {
                 d->modifiedItemHints << ids[i];
+            }
             else
+            {
                 d->rescanItemHints << ids[i];
+            }
         }
     }
 }
@@ -184,7 +204,9 @@ void CollectionScanner::recordHints(const QList<ItemChangeHint>& hints)
 void CollectionScanner::loadNameFilters()
 {
     if (!d->nameFilters.isEmpty())
+    {
         return;
+    }
 
     QStringList imageFilter, audioFilter, videoFilter;
     DatabaseAccess().db()->getFilterSettings(&imageFilter, &videoFilter, &audioFilter);
@@ -197,13 +219,16 @@ void CollectionScanner::loadNameFilters()
     d->nameFilters = d->imageFilterSet + d->audioFilterSet + d->videoFilterSet;
 }
 
-void CollectionScanner::setObserver(CollectionScannerObserver *observer)
+void CollectionScanner::setObserver(CollectionScannerObserver* observer)
 {
     d->observer = observer;
 }
 
 void CollectionScanner::completeScan()
 {
+    QTime time;
+    time.start();
+
     emit startCompleteScan();
 
     // lock database
@@ -220,7 +245,9 @@ void CollectionScanner::completeScan()
         // count for progress info
         int count = 0;
         foreach (const CollectionLocation& location, allLocations)
+        {
             count += countItemsInFolder(location.albumRootPath());
+        }
 
         emit totalFilesToScan(count);
     }
@@ -233,7 +260,9 @@ void CollectionScanner::completeScan()
 
     // if we have no hints to follow, clean up all stale albums
     if (d->albumHints.isEmpty())
+    {
         DatabaseAccess().db()->deleteStaleAlbums();
+    }
 
     scanForStaleAlbums(allLocations);
 
@@ -244,10 +273,14 @@ void CollectionScanner::completeScan()
     }
 
     if (d->wantSignals)
+    {
         emit startScanningAlbumRoots();
+    }
 
     foreach (const CollectionLocation& location, allLocations)
+    {
         scanAlbumRoot(location);
+    }
 
     // do not continue to clean up without a complete scan!
     if (!d->checkObserver())
@@ -257,13 +290,14 @@ void CollectionScanner::completeScan()
     }
 
     updateRemovedItemsTime();
+
     // Items may be set to status removed, without being definitely deleted.
     // This deletion shall be done after a certain time, as checked by checkedDeleteRemoved
     if (checkDeleteRemoved())
     {
         // Definitely delete items which are marked as removed.
         // Only do this in a complete scan!
-        DatabaseAccess().db()->deleteRemovedItems(d->scannedAlbums);
+        DatabaseAccess().db()->deleteRemovedItems();
         resetDeleteRemovedSettings();
     }
     else
@@ -275,6 +309,8 @@ void CollectionScanner::completeScan()
     markDatabaseAsScanned();
 
     emit finishedCompleteScan();
+
+    kDebug() << "Complete scan took:" << time.elapsed() << "msecs.";
 }
 
 void CollectionScanner::partialScan(const QString& filePath)
@@ -282,7 +318,9 @@ void CollectionScanner::partialScan(const QString& filePath)
     QString albumRoot = CollectionManager::instance()->albumRootPath(filePath);
 
     if (albumRoot.isNull())
+    {
         return;
+    }
 
     QString album = CollectionManager::instance()->album(filePath);
     partialScan(albumRoot, album);
@@ -301,7 +339,7 @@ void CollectionScanner::partialScan(const QString& albumRoot, const QString& alb
     {
         // Install ScanController::instance()->suspendCollectionScan around your DatabaseTransaction
         kError() << "Detected an active database transaction when starting a collection scan. "
-                         "Please report this error.";
+                 "Please report this error.";
         return;
     }
 
@@ -319,7 +357,9 @@ void CollectionScanner::partialScan(const QString& albumRoot, const QString& alb
     // if we have no hints to follow, clean up all stale albums
     // Hint: Rethink with next major db update
     if (d->albumHints.isEmpty())
+    {
         DatabaseAccess().db()->deleteStaleAlbums();
+    }
 
     //TODO: This can be optimized, no need to always scan the whole location
     scanForStaleAlbums(QList<CollectionLocation>() << location);
@@ -331,9 +371,13 @@ void CollectionScanner::partialScan(const QString& albumRoot, const QString& alb
     }
 
     if (album == "/")
+    {
         scanAlbumRoot(location);
+    }
     else
+    {
         scanAlbum(location, album);
+    }
 
     if (!d->checkObserver())
     {
@@ -351,7 +395,9 @@ qlonglong CollectionScanner::scanFile(const QString& filePath, FileScanMode mode
     QString albumRoot = CollectionManager::instance()->albumRootPath(dirPath);
 
     if (albumRoot.isNull())
+    {
         return -1;
+    }
 
     QString album = CollectionManager::instance()->album(dirPath);
     return scanFile(albumRoot, album, info.fileName(), mode);
@@ -369,7 +415,7 @@ qlonglong CollectionScanner::scanFile(const QString& albumRoot, const QString& a
     {
         // Install ScanController::instance()->suspendCollectionScan around your DatabaseTransaction
         kError() << "Detected an active database transaction when starting a collection file scan. "
-                         "Please report this error.";
+                 "Please report this error.";
         return -1;
     }
 
@@ -411,6 +457,7 @@ qlonglong CollectionScanner::scanFile(const QString& albumRoot, const QString& a
     else
     {
         ItemScanInfo scanInfo = DatabaseAccess().db()->getItemScanInfo(imageId);
+
         switch (mode)
         {
             case NormalScan:
@@ -431,13 +478,15 @@ qlonglong CollectionScanner::scanFile(const QString& albumRoot, const QString& a
 void CollectionScanner::scanFile(const ImageInfo& info, FileScanMode mode)
 {
     if (info.isNull())
+    {
         return;
+    }
 
     if (DatabaseAccess().backend()->isInTransaction())
     {
         // Install ScanController::instance()->suspendCollectionScan around your DatabaseTransaction
         kError() << "Detected an active database transaction when starting a collection file scan. "
-                         "Please report this error.";
+                 "Please report this error.";
         return;
     }
 
@@ -463,7 +512,9 @@ void CollectionScanner::scanFile(const ImageInfo& info, FileScanMode mode)
 void CollectionScanner::scanAlbumRoot(const CollectionLocation& location)
 {
     if (d->wantSignals)
+    {
         emit startScanningAlbumRoot(location.albumRootPath());
+    }
 
     /*
     QDir dir(location.albumRootPath());
@@ -479,29 +530,42 @@ void CollectionScanner::scanAlbumRoot(const CollectionLocation& location)
     scanAlbum(location, "/");
 
     if (d->wantSignals)
+    {
         emit finishedScanningAlbumRoot(location.albumRootPath());
+    }
 }
 
 void CollectionScanner::scanForStaleAlbums(QList<CollectionLocation> locations)
 {
+    Q_UNUSED(locations);
+
     if (d->wantSignals)
+    {
         emit startScanningForStaleAlbums();
+    }
 
     QList<AlbumShortInfo> albumList = DatabaseAccess().db()->getAlbumShortInfos();
     QList<int> toBeDeleted;
 
+    /* see #231598
     QHash<int, CollectionLocation> albumRoots;
     foreach (const CollectionLocation& location, locations)
+    {
         albumRoots[location.id()] = location;
+    }
+    */
 
     QList<AlbumShortInfo>::const_iterator it;
+
     for (it = albumList.constBegin(); it != albumList.constEnd(); ++it)
     {
-        CollectionLocation location = albumRoots.value((*it).albumRootId);
+        CollectionLocation location = CollectionManager::instance()->locationForAlbumRootId((*it).albumRootId);
+
         // Only handle albums on available locations
-        if (!location.isNull())
+        if (location.isAvailable())
         {
             QFileInfo fileInfo(location.albumRootPath() + (*it).relativePath);
+
             if (!fileInfo.exists() || !fileInfo.isDir())
             {
                 toBeDeleted << (*it).id;
@@ -519,17 +583,21 @@ void CollectionScanner::scanForStaleAlbums(QList<CollectionLocation> locations)
         // go through all album copy/move hints
         QHash<CollectionScannerHints::DstPath, CollectionScannerHints::Album>::const_iterator it;
         int toBeDeletedIndex;
+
         for (it = d->albumHints.constBegin(); it != d->albumHints.constEnd(); ++it)
         {
             // if the src entry of a hint is found in toBeDeleted, we have a move/rename, no copy. Handle these here.
             toBeDeletedIndex = toBeDeleted.indexOf(it.value().albumId);
+
             if (toBeDeletedIndex != -1)
             {
                 // check for existence of target
-                CollectionLocation location = albumRoots.value(it.key().albumRootId);
-                if (!location.isNull())
+                CollectionLocation location = CollectionManager::instance()->locationForAlbumRootId(it.key().albumRootId);
+
+                if (location.isAvailable())
                 {
                     QFileInfo fileInfo(location.albumRootPath() + it.key().relativePath);
+
                     if (fileInfo.exists() && fileInfo.isDir())
                     {
                         // Just set a new root/relativePath to the album. Further scanning will care for all cases or error.
@@ -545,22 +613,22 @@ void CollectionScanner::scanForStaleAlbums(QList<CollectionLocation> locations)
     safelyRemoveAlbums(toBeDeleted);
 
     if (d->wantSignals)
+    {
         emit finishedScanningForStaleAlbums();
+    }
 }
 
 void CollectionScanner::safelyRemoveAlbums(const QList<int>& albumIds)
 {
     // Remove the items (orphan items, detach them from the album, but keep entries for a certain time)
     // Make album orphan (no album root, keep entries until next application start)
+    DatabaseAccess access;
+    DatabaseTransaction transaction(&access);
+    foreach (int albumId, albumIds)
     {
-        DatabaseAccess access;
-        DatabaseTransaction transaction(&access);
-        foreach (int albumId, albumIds)
-        {
-            access.db()->removeItemsFromAlbum(albumId);
-            access.db()->makeStaleAlbum(albumId);
-            d->removedItems();
-        }
+        access.db()->removeItemsFromAlbum(albumId);
+        access.db()->makeStaleAlbum(albumId);
+        d->removedItems();
     }
 }
 
@@ -579,6 +647,7 @@ int CollectionScanner::checkAlbum(const CollectionLocation& location, const QStr
 
         // have album this one was copied from?
         CollectionScannerHints::Album src = d->albumHints.value(CollectionScannerHints::DstPath(location.id(), album));
+
         if (!src.isNull())
         {
             //kDebug() << "Identified album" << src.albumId << "as source of new album" << fi.filePath();
@@ -602,12 +671,14 @@ void CollectionScanner::scanAlbum(const CollectionLocation& location, const QStr
     if ( !dir.exists() || !dir.isReadable() )
     {
         kWarning() << "Folder does not exist or is not readable: "
-                        << dir.path();
+                   << dir.path();
         return;
     }
 
     if (d->wantSignals)
+    {
         emit startScanningAlbum(location.albumRootPath(), album);
+    }
 
     int albumID = checkAlbum(location, album);
 
@@ -616,6 +687,7 @@ void CollectionScanner::scanAlbum(const CollectionLocation& location, const QStr
     // create a hash filename -> index in list
     QHash<QString, int> fileNameIndexHash;
     QSet<qlonglong> itemIdSet;
+
     for (int i = 0; i < scanInfos.size(); ++i)
     {
         fileNameIndexHash[scanInfos[i].itemName] = i;
@@ -623,29 +695,38 @@ void CollectionScanner::scanAlbum(const CollectionLocation& location, const QStr
     }
 
     const QFileInfoList list = dir.entryInfoList(QDir::AllDirs | QDir::Files  | QDir::NoDotAndDotDot);
+
     QFileInfoList::const_iterator fi;
 
     int counter = -1;
+
     for (fi = list.constBegin(); fi != list.constEnd(); ++fi)
     {
         if (!d->checkObserver())
+        {
             return; // return directly, do not go to cleanup code after loop!
+        }
 
         counter++;
+
         if (d->wantSignals && counter && (counter % 100 == 0))
         {
             emit scannedFiles(counter);
             counter = 0;
         }
 
-        if ( fi->isFile())
+        if (fi->isFile())
         {
             // filter with name filter
             QString suffix = fi->suffix().toLower();
+
             if (!d->nameFilters.contains(suffix))
+            {
                 continue;
+            }
 
             int index = fileNameIndexHash.value(fi->fileName(), -1);
+
             if (index != -1)
             {
                 // mark item as "seen"
@@ -675,17 +756,24 @@ void CollectionScanner::scanAlbum(const CollectionLocation& location, const QStr
         else if ( fi->isDir() )
         {
             QString subalbum;
+
             if (album == "/")
+            {
                 subalbum = '/' + fi->fileName();
+            }
             else
+            {
                 subalbum = album + '/' + fi->fileName();
+            }
 
             scanAlbum( location, subalbum );
         }
     }
 
     if (d->wantSignals && counter)
+    {
         emit scannedFiles(counter);
+    }
 
     // Mark items in the db which we did not see on disk.
     if (!itemIdSet.isEmpty())
@@ -698,7 +786,9 @@ void CollectionScanner::scanAlbum(const CollectionLocation& location, const QStr
     d->scannedAlbums << albumID;
 
     if (d->wantSignals)
+    {
         emit finishedScanningAlbum(location.albumRootPath(), album, list.count());
+    }
 }
 
 void CollectionScanner::scanFileNormal(const QFileInfo& fi, const ItemScanInfo& scanInfo)
@@ -718,17 +808,23 @@ void CollectionScanner::scanFileNormal(const QFileInfo& fi, const ItemScanInfo&
     {
         // compare modification date
         QDateTime fiModifyDate = fi.lastModified();
+
         if (fiModifyDate != scanInfo.modificationDate)
         {
             // allow a "modify window" of one second.
             // FAT filesystems store the modify date in 2-second resolution.
             int diff = fiModifyDate.secsTo(scanInfo.modificationDate);
+
             if (abs(diff) > 1)
             {
                 // file has been modified
                 scanModifiedFile(fi, scanInfo);
             }
         }
+        else if ((int)fi.size() != scanInfo.fileSize)
+        {
+            scanModifiedFile(fi, scanInfo);
+        }
     }
 }
 
@@ -739,21 +835,31 @@ qlonglong CollectionScanner::scanNewFile(const QFileInfo& info, int albumId)
 
     // Check copy/move hints for single items
     qlonglong srcId = d->itemHints.value(NewlyAppearedFile(albumId, info.fileName()));
+
     if (srcId != 0)
+    {
         scanner.copiedFrom(albumId, srcId);
+    }
     else
     {
         // Check copy/move hints for whole albums
         int srcAlbum = d->establishedSourceAlbums.value(albumId);
+
         if (srcAlbum)
+        {
             // if we have one source album, find out if there is a file with the same name
             srcId = DatabaseAccess().db()->getImageId(srcAlbum, info.fileName());
+        }
 
         if (srcId != 0)
+        {
             scanner.copiedFrom(albumId, srcId);
+        }
         else
+        {
             // Establishing identity with the unique hsah
             scanner.newFile(albumId);
+        }
     }
 
     return scanner.id();
@@ -784,7 +890,9 @@ void CollectionScanner::rescanFile(const QFileInfo& info, const ItemScanInfo& sc
 void CollectionScanner::copyFileProperties(const ImageInfo& source, const ImageInfo& dest)
 {
     if (source.isNull() || dest.isNull())
+    {
         return;
+    }
 
     ImageScanner::copyProperties(source.id(), dest.id());
 }
@@ -794,14 +902,18 @@ int CollectionScanner::countItemsInFolder(const QString& directory)
     int items = 0;
 
     QDir dir( directory );
+
     if ( !dir.exists() || !dir.isReadable() )
+    {
         return 0;
+    }
 
     QFileInfoList list = dir.entryInfoList();
 
     items += list.count();
 
     QFileInfoList::const_iterator fi;
+
     for (fi = list.constBegin(); fi != list.constEnd(); ++fi)
     {
         if ( fi->isDir() &&
@@ -820,13 +932,21 @@ DatabaseItem::Category CollectionScanner::category(const QFileInfo& info)
     QString suffix = info.suffix().toLower();
 
     if (d->imageFilterSet.contains(suffix))
+    {
         return DatabaseItem::Image;
+    }
     else if (d->audioFilterSet.contains(suffix))
+    {
         return DatabaseItem::Audio;
+    }
     else if (d->videoFilterSet.contains(suffix))
+    {
         return DatabaseItem::Video;
+    }
     else
+    {
         return DatabaseItem::Other;
+    }
 }
 
 void CollectionScanner::markDatabaseAsScanned()
@@ -875,15 +995,24 @@ bool CollectionScanner::checkDeleteRemoved()
     QString removedItemsTimeString = access.db()->getSetting("RemovedItemsTime");
 
     if (removedItemsTimeString.isNull())
+    {
         return false;
+    }
 
     // retrieve last time removed items were (definitely) deleted from db
     QString deleteRemovedTimeString = access.db()->getSetting("DeleteRemovedTime");
     QDateTime removedItemsTime, deleteRemovedTime;
+
     if (!removedItemsTimeString.isNull())
+    {
         removedItemsTime = QDateTime::fromString(removedItemsTimeString, Qt::ISODate);
+    }
+
     if (!deleteRemovedTimeString.isNull())
+    {
         deleteRemovedTime = QDateTime::fromString(deleteRemovedTimeString, Qt::ISODate);
+    }
+
     QDateTime now = QDateTime::currentDateTime();
 
     // retrieve number of complete collection scans since the last time that removed items were deleted
@@ -891,13 +1020,17 @@ bool CollectionScanner::checkDeleteRemoved()
 
     // No removed items? No need to delete any
     if (!removedItemsTime.isValid())
+    {
         return false;
+    }
 
     // give at least a week between removed item deletions
     if (deleteRemovedTime.isValid())
     {
         if (deleteRemovedTime.daysTo(now) <= 7)
+        {
             return false;
+        }
     }
 
     // Now look at time since items were removed, and the number of complete scans
@@ -916,8 +1049,11 @@ bool CollectionScanner::checkDeleteRemoved()
 void CollectionScanner::scanForStaleAlbums()
 {
     QStringList albumRootPaths = CollectionManager::instance()->allAvailableAlbumRootPaths();
+
     for (QStringList::const_iterator it = albumRootPaths.constBegin(); it != albumRootPaths.constEnd(); ++it)
+    {
         scanForStaleAlbums(*it);
+    }
 }
 
 void CollectionScanner::scanForStaleAlbums(const QString& albumRoot)
@@ -927,11 +1063,15 @@ void CollectionScanner::scanForStaleAlbums(const QString& albumRoot)
     QList<AlbumShortInfo> toBeDeleted;
 
     QList<AlbumShortInfo>::const_iterator it;
+
     for (it = albumList.constBegin(); it != albumList.constEnd(); ++it)
     {
         QFileInfo fileInfo((*it).albumRoot + (*it).url);
+
         if (!fileInfo.exists() || !fileInfo.isDir())
+        {
             m_foldersToBeDeleted << (*it);
+        }
     }
 }
 
@@ -939,10 +1079,12 @@ QStringList CollectionScanner::formattedListOfStaleAlbums()
 {
     QStringList list;
     QList<AlbumShortInfo>::const_iterator it;
+
     for (it = m_foldersToBeDeleted.constBegin(); it != m_foldersToBeDeleted.constEnd(); ++it)
     {
         list << (*it).url;
     }
+
     return list;
 }
 
@@ -951,6 +1093,7 @@ void CollectionScanner::removeStaleAlbums()
     DatabaseAccess access;
     DatabaseTransaction transaction(&access);
     QList<AlbumShortInfo>::const_iterator it;
+
     for (it = m_foldersToBeDeleted.constBegin(); it != m_foldersToBeDeleted.constEnd(); ++it)
     {
         kDebug() << "Removing album " << (*it).albumRoot + '/' + (*it).url;
@@ -964,6 +1107,7 @@ QStringList CollectionScanner::formattedListOfStaleFiles()
 
     DatabaseAccess access;
     QList< QPair<QString,int> >::const_iterator it;
+
     for (it = m_filesToBeDeleted.constBegin(); it != m_filesToBeDeleted.constEnd(); ++it)
     {
         QString location = " (" + access.db()->getAlbumPath((*it).second) + ')';
@@ -979,10 +1123,11 @@ void CollectionScanner::removeStaleFiles()
     DatabaseAccess access;
     DatabaseTransaction transaction(&access);
     QList< QPair<QString,int> >::const_iterator it;
+
     for (it = m_filesToBeDeleted.constBegin(); it != m_filesToBeDeleted.constEnd(); ++it)
     {
         kDebug() << "Removing: " << (*it).first << " in "
-                << (*it).second;
+                 << (*it).second;
         access.db()->deleteItem( (*it).second, (*it).first );
     }
 }
@@ -991,8 +1136,11 @@ void CollectionScanner::scanAlbums()
 {
     QStringList albumRootPaths = CollectionManager::instance()->allAvailableAlbumRootPaths();
     int count = 0;
+
     for (QStringList::const_iterator it = albumRootPaths.constBegin(); it != albumRootPaths.constEnd(); ++it)
+    {
         count += countItemsInFolder(*it);
+    }
 
     emit totalFilesToScan(count);
 
@@ -1011,7 +1159,7 @@ void CollectionScanner::scanAlbums()
 
 void CollectionScanner::scan(const QString& folderPath)
 {
-    CollectionManager *manager = CollectionManager::instance();
+    CollectionManager* manager = CollectionManager::instance();
     KUrl url;
     url.setPath(folderPath);
     QString albumRoot = manager->albumRootPath(url);
@@ -1042,6 +1190,7 @@ void CollectionScanner::scan(const QString& albumRoot, const QString& album)
         QStringList fileList(dir.entryList(QDir::Dirs | QDir::NoDotAndDotDot));
 
         DatabaseTransaction transaction;
+
         for (QStringList::const_iterator fileIt = fileList.constBegin(); fileIt != fileList.constEnd(); ++fileIt)
         {
             scanAlbum(albumRoot, '/' + (*fileIt));
@@ -1073,6 +1222,7 @@ void CollectionScanner::scanAlbum(const QString& albumRoot, const QString& album
     // - Does not add stale albums to m_foldersToBeDeleted.
 
     QDir dir( albumRoot + album );
+
     if ( !dir.exists() || !dir.isReadable() )
     {
         kWarning() << "Folder does not exist or is not readable: " << dir.path();
@@ -1101,6 +1251,7 @@ void CollectionScanner::scanAlbum(const QString& albumRoot, const QString& album
     }
 
     const QFileInfoList list = dir.entryInfoList(m_nameFilters, QDir::AllDirs | QDir::Files  | QDir::NoDotAndDotDot /*not CaseSensitive*/);
+
     QFileInfoList::const_iterator fi;
 
     for (fi = list.constBegin(); fi != list.constEnd(); ++fi)
@@ -1132,9 +1283,11 @@ void CollectionScanner::scanAlbum(const QString& albumRoot, const QString& album
     if (!filesFoundInDB.isEmpty())
     {
         QSetIterator<QString> it(filesFoundInDB);
+
         while (it.hasNext())
         {
             QPair<QString,int> pair(it.next(),albumID);
+
             if (m_filesToBeDeleted.indexOf(pair) == -1)
             {
                 m_filesToBeDeleted << pair;
@@ -1155,6 +1308,7 @@ void CollectionScanner::updateItemsWithoutDate()
 
     {
         DatabaseTransaction transaction;
+
         for (QStringList::const_iterator it = urls.constBegin(); it != urls.constEnd(); ++it)
         {
             emit scanningFile(*it);
@@ -1192,14 +1346,18 @@ int CollectionScanner::countItemsInFolder(const QString& directory)
     int items = 0;
 
     QDir dir( directory );
+
     if ( !dir.exists() || !dir.isReadable() )
+    {
         return 0;
+    }
 
     QFileInfoList list = dir.entryInfoList();
 
     items += list.count();
 
     QFileInfoList::const_iterator fi;
+
     for (fi = list.constBegin(); fi != list.constEnd(); ++fi)
     {
         if ( fi->isDir()           &&
@@ -1276,7 +1434,7 @@ void CollectionScanner::updateItemDate(int albumID, const QString& albumRoot, co
 }
 
 void CollectionScanner::updateItemDate(Digikam::DatabaseAccess& access, int albumID,
-                                 const QString& albumRoot, const QString& album, const QString& fileName)
+                                       const QString& albumRoot, const QString& album, const QString& fileName)
 {
     QString filePath = albumRoot + album + '/' + fileName;
 
