@@ -7,9 +7,9 @@
  * Description : Haar Database interface
  *
  * Copyright (C) 2003 by Ricardo Niederberger Cabral <nieder at mail dot ru>
- * Copyright (C) 2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
- * Copyright (C) 2009 by Andi Clemens <andi dot clemens at gmx dot net>
+ * Copyright (C) 2009-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2009-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * Copyright (C) 2009-2010 by Andi Clemens <andi dot clemens at gmx dot net>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -26,13 +26,13 @@
 
 #include "haariface.h"
 
-// C++ includes.
+// C++ includes
 
 #include <fstream>
 #include <cmath>
 #include <cstring>
 
-// Qt includes.
+// Qt includes
 
 #include <QByteArray>
 #include <QDataStream>
@@ -40,12 +40,12 @@
 #include <QImageReader>
 #include <QMap>
 
-// KDE includes.
+// KDE includes
 
-#include <kdebug.h>
 #include <kurl.h>
+#include <kdebug.h>
 
-// Local includes.
+// Local includes
 
 #include "jpegutils.h"
 #include "dimg.h"
@@ -56,14 +56,15 @@
 #include "databasebackend.h"
 #include "searchxml.h"
 #include "haar.h"
-#include "imagecomments_p.h"
-#include "imageposition_p.h"
+#include "sqlquery.h"
 
 using namespace std;
 
 namespace Digikam
 {
 
+typedef QMap<qlonglong, Haar::SignatureData> SignatureCache;
+
 /** This class encapsulates the Haar signature in a QByteArray
  *  that can be stored as a BLOB in the database.
  *
@@ -72,43 +73,47 @@ namespace Digikam
  */
 class DatabaseBlob
 {
-
 public:
 
     enum { Version = 1 };
 
 public:
 
-    DatabaseBlob(){}
+    DatabaseBlob() {}
 
     /** Read the QByteArray into the Haar::SignatureData.
      */
-    void read(const QByteArray &array, Haar::SignatureData *data)
+    void read(const QByteArray& array, Haar::SignatureData* data)
     {
         QDataStream stream(array);
 
         // check version
         qint32 version;
         stream >> version;
+
         if (version != Version)
         {
-            kError(50003) << "Unsupported binary version of Haar Blob in database" << endl;
+            kError() << "Unsupported binary version of Haar Blob in database";
             return;
         }
 
         stream.setVersion(QDataStream::Qt_4_3);
 
         // read averages
-        for (int i=0; i<3; i++)
+        for (int i=0; i<3; ++i)
+        {
             stream >> data->avg[i];
+        }
 
         // read coefficients
-        for (int i=0; i<3; i++)
-            for (int j=0; j<Haar::NumberOfCoefficients; j++)
+        for (int i=0; i<3; ++i)
+            for (int j=0; j<Haar::NumberOfCoefficients; ++j)
+            {
                 stream >> data->sig[i][j];
+            }
     }
 
-    QByteArray write(Haar::SignatureData *data)
+    QByteArray write(Haar::SignatureData* data)
     {
         QByteArray array;
         array.reserve(sizeof(qint32) + 3*sizeof(double) + 3*sizeof(qint32)*Haar::NumberOfCoefficients);
@@ -119,71 +124,154 @@ public:
         stream << (qint32)Version;
 
         // write averages
-        for (int i=0; i<3; i++)
+        for (int i=0; i<3; ++i)
+        {
             stream << data->avg[i];
+        }
 
         // write coefficients
-        for (int i=0; i<3; i++)
-            for (int j=0; j<Haar::NumberOfCoefficients; j++)
+        for (int i=0; i<3; ++i)
+            for (int j=0; j<Haar::NumberOfCoefficients; ++j)
+            {
                 stream << data->sig[i][j];
+            }
 
         return array;
     }
 };
 
-class HaarIfacePriv
-{
+// -----------------------------------------------------------------------------------------------------
 
+class HaarIface::HaarIfacePriv
+{
 public:
 
     HaarIfacePriv()
     {
-        data          = 0;
-        bin           = 0;
-        sigMap        = 0;
-        useCachedSigs = false;
+        data              = 0;
+        bin               = 0;
+        signatureCache    = 0;
+        useSignatureCache = false;
+
+        signatureQuery = QString("SELECT M.imageid, 0, M.matrix "
+                                 " FROM ImageHaarMatrix AS M "
+                                 "    INNER JOIN Images ON Images.id=M.imageid "
+                                 " WHERE Images.status=1; ");
+
+        signatureByAlbumRootsQuery = QString("SELECT M.imageid, Albums.albumRoot, M.matrix "
+                                             " FROM ImageHaarMatrix AS M "
+                                             "    INNER JOIN Images ON Images.id=M.imageid "
+                                             "    INNER JOIN Albums ON Albums.id=Images.album"
+                                             " WHERE Images.status=1;");
     }
 
     ~HaarIfacePriv()
     {
         delete data;
         delete bin;
-        delete sigMap;
+        delete signatureCache;
     }
 
     void createLoadingBuffer()
     {
         if (!data)
+        {
             data = new Haar::ImageData;
+        }
     }
 
     void createWeightBin()
     {
         if (!bin)
+        {
             bin = new Haar::WeightBin;
+        }
     }
 
-    void enableCachedSignatures(bool cached)
+    void setSignatureCacheEnabled(bool cache, const QSet<qlonglong>& imageIds)
     {
-        if (sigMap)
-            delete sigMap;
+        setSignatureCacheEnabled(cache);
 
-        if (cached)
-            sigMap = new QMap<qlonglong, Haar::SignatureData>();
+        // stop here if we disable cached signatures
+        if (!cache || imageIds.isEmpty())
+        {
+            return;
+        }
 
-        useCachedSigs = cached;
+        // Remove all ids from the fully created signatureCache that are not needed for the duplicates search.
+        // This is usually faster then starting a query for every single id in imageIds.
+        //
+        // It might look like a waste of resources, but I tested this quite intense.
+        // Getting all signatures and removing the not wanted ones is really more efficient
+        // then doing X queries (where X = imageIds.count())
+
+        for (SignatureCache::iterator it = signatureCache->begin();
+             it != signatureCache->end(); )
+        {
+            if (!imageIds.contains(it.key()))
+            {
+                it = signatureCache->erase(it);
+            }
+            else
+            {
+                ++it;
+            }
+        }
     }
 
-    bool                                  useCachedSigs;
-    Haar::ImageData                      *data;
-    Haar::WeightBin                      *bin;
-    QMap<qlonglong, Haar::SignatureData> *sigMap;
+    void setSignatureCacheEnabled(bool cache)
+    {
+        delete signatureCache;
+	signatureCache = 0;
 
-    QSet<int> albumRootsToSearch;
+        if (cache)
+        {
+            signatureCache = new SignatureCache();
+        }
+
+        useSignatureCache = cache;
+
+        // stop here if we disable cached signatures
+        if (!cache)
+        {
+            return;
+        }
+
+        // Variables for data read from DB
+        DatabaseAccess      access;
+        DatabaseBlob        blob;
+        qlonglong           imageid;
+        Haar::SignatureData targetSig;
+
+        // reference for easier access
+        SignatureCache& signatureCache = *this->signatureCache;
+
+        SqlQuery query = access.backend()->prepareQuery(signatureQuery);
+
+        if (!access.backend()->exec(query))
+        {
+            return;
+        }
+
+        while (query.next())
+        {
+            imageid = query.value(0).toLongLong();
+            blob.read(query.value(2).toByteArray(), &targetSig);
+            signatureCache[imageid] = targetSig;
+        }
+    }
+
+    bool             useSignatureCache;
+    Haar::ImageData* data;
+    Haar::WeightBin* bin;
+    SignatureCache*  signatureCache;
+    QString          signatureQuery;
+    QString          signatureByAlbumRootsQuery;
+    QSet<int>        albumRootsToSearch;
 };
 
 HaarIface::HaarIface()
-         : d(new HaarIfacePriv())
+    : d(new HaarIfacePriv())
 {
 }
 
@@ -210,31 +298,45 @@ int HaarIface::preferredSize()
 bool HaarIface::indexImage(const QString& filename)
 {
     QImage image = loadQImage(filename);
+
     if (image.isNull())
+    {
         return false;
+    }
+
     return indexImage(filename, image);
 }
 
-bool HaarIface::indexImage(const QString& filename, const QImage &image)
+bool HaarIface::indexImage(const QString& filename, const QImage& image)
 {
     ImageInfo info(KUrl::fromPath(filename));
+
     if (info.isNull())
+    {
         return false;
+    }
+
     return indexImage(info.id(), image);
 }
 
-bool HaarIface::indexImage(const QString& filename, const DImg &image)
+bool HaarIface::indexImage(const QString& filename, const DImg& image)
 {
     ImageInfo info(KUrl::fromPath(filename));
+
     if (info.isNull())
+    {
         return false;
+    }
+
     return indexImage(info.id(), image);
 }
 
 bool HaarIface::indexImage(qlonglong imageid, const QImage& image)
 {
     if (image.isNull())
+    {
         return false;
+    }
 
     d->createLoadingBuffer();
     d->data->fillPixelData(image);
@@ -245,7 +347,9 @@ bool HaarIface::indexImage(qlonglong imageid, const QImage& image)
 bool HaarIface::indexImage(qlonglong imageid, const DImg& image)
 {
     if (image.isNull())
+    {
         return false;
+    }
 
     d->createLoadingBuffer();
     d->data->fillPixelData(image);
@@ -280,7 +384,7 @@ bool HaarIface::indexImage(qlonglong imageid)
     return true;
 }
 
-QString HaarIface::signatureAsText(const QImage &image)
+QString HaarIface::signatureAsText(const QImage& image)
 {
     d->createLoadingBuffer();
     d->data->fillPixelData(image);
@@ -312,27 +416,46 @@ QList<qlonglong> HaarIface::bestMatchesForImage(const QImage& image, int numberO
 QList<qlonglong> HaarIface::bestMatchesForImage(qlonglong imageid, int numberOfResults, SketchType type)
 {
     Haar::SignatureData sig;
+
     if (!retrieveSignatureFromDB(imageid, &sig))
+    {
         return QList<qlonglong>();
+    }
 
     return bestMatches(&sig, numberOfResults, type);
 }
 
 QList<qlonglong> HaarIface::bestMatchesForImageWithThreshold(qlonglong imageid, double requiredPercentage,
-                                                             SketchType type)
+        SketchType type)
 {
-    Haar::SignatureData sig;
-    if (!retrieveSignatureFromDB(imageid, &sig))
-        return QList<qlonglong>();
+    if ( !d->useSignatureCache || (d->signatureCache->isEmpty() && d->useSignatureCache) )
+    {
+        Haar::SignatureData sig;
 
-    return bestMatchesWithThreshold(&sig, requiredPercentage, type);
+        if (!retrieveSignatureFromDB(imageid, &sig))
+        {
+            return QList<qlonglong>();
+        }
+
+        return bestMatchesWithThreshold(&sig, requiredPercentage, type);
+    }
+    else
+    {
+        // reference for easier access
+        SignatureCache& signatureCache = *d->signatureCache;
+        Haar::SignatureData& sig = signatureCache[imageid];
+        return bestMatchesWithThreshold(&sig, requiredPercentage, type);
+    }
 }
 
 QList<qlonglong> HaarIface::bestMatchesForFile(const QString& filename, int numberOfResults, SketchType type)
 {
     QImage image = loadQImage(filename);
+
     if (image.isNull())
+    {
         return QList<qlonglong>();
+    }
 
     return bestMatchesForImage(image, numberOfResults, type);
 }
@@ -348,7 +471,7 @@ QList<qlonglong> HaarIface::bestMatchesForSignature(const QString& signature, in
     return bestMatches(&sig, numberOfResults, type);
 }
 
-QList<qlonglong> HaarIface::bestMatches(Haar::SignatureData *querySig, int numberOfResults, SketchType type)
+QList<qlonglong> HaarIface::bestMatches(Haar::SignatureData* querySig, int numberOfResults, SketchType type)
 {
     QMap<qlonglong, double> scores = searchDatabase(querySig, type);
 
@@ -359,7 +482,8 @@ QList<qlonglong> HaarIface::bestMatches(Haar::SignatureData *querySig, int numbe
     bool initialFill = false;
     double score, worstScore, bestScore;
     qlonglong id;
-    for (QMap<qlonglong, double>::iterator it = scores.begin(); it != scores.end(); ++it)
+
+    for (QMap<qlonglong, double>::const_iterator it = scores.constBegin(); it != scores.constEnd(); ++it)
     {
         score = it.value();
         id    = it.key();
@@ -376,6 +500,7 @@ QList<qlonglong> HaarIface::bestMatches(Haar::SignatureData *querySig, int numbe
             QMap<double, qlonglong>::iterator last = bestMatches.end();
             --last;
             worstScore = last.key();
+
             // if the new entry has a higher score, put it in the list and remove that last one
             if (score < worstScore)
             {
@@ -385,33 +510,38 @@ QList<qlonglong> HaarIface::bestMatches(Haar::SignatureData *querySig, int numbe
             else if (score == worstScore)
             {
                 bestScore = bestMatches.begin().key();
+
                 // if the score is identical for all entries, increase the maximum result number
                 if (score == bestScore)
+                {
                     bestMatches.insert(score, id);
+                }
             }
         }
     }
 
-/*
-    for (QMap<double, qlonglong>::iterator it = bestMatches.begin(); it != bestMatches.end(); ++it)
-        kDebug(50003) << it.key() << it.value();
-*/
+    /*
+        for (QMap<double, qlonglong>::iterator it = bestMatches.begin(); it != bestMatches.end(); ++it)
+            kDebug() << it.key() << it.value();
+    */
     return bestMatches.values();
 }
 
-QList<qlonglong> HaarIface::bestMatchesWithThreshold(Haar::SignatureData *querySig, double requiredPercentage,
-                                                     SketchType type)
+QList<qlonglong> HaarIface::bestMatchesWithThreshold(Haar::SignatureData* querySig, double requiredPercentage,
+        SketchType type)
 {
     QMap<qlonglong, double> scores = searchDatabase(querySig, type);
     double lowest, highest;
     getBestAndWorstPossibleScore(querySig, type, &lowest, &highest);
-    double range = highest - lowest;
+
+    double range         = highest - lowest;
     double requiredScore = lowest + range * (1.0 - requiredPercentage);
 
     QMultiMap<double, qlonglong> bestMatches;
     double score, percentage;
     qlonglong id;
-    for (QMap<qlonglong, double>::iterator it = scores.begin(); it != scores.end(); ++it)
+
+    for (QMap<qlonglong, double>::const_iterator it = scores.constBegin(); it != scores.constEnd(); ++it)
     {
         score = it.value();
         id    = it.key();
@@ -426,18 +556,20 @@ QList<qlonglong> HaarIface::bestMatchesWithThreshold(Haar::SignatureData *queryS
     // Debug output
     if (bestMatches.count() > 1)
     {
-        kDebug(50003) << "Duplicates with id and score:";
-        for (QMultiMap<double, qlonglong>::iterator it = bestMatches.begin(); it != bestMatches.end(); ++it)
+        kDebug() << "Duplicates with id and score:";
+
+        for (QMultiMap<double, qlonglong>::const_iterator it = bestMatches.constBegin(); it != bestMatches.constEnd(); ++it)
         {
-            kDebug(50003) << it.value() << QString::number(it.key() * 100)+QChar('%');
+            kDebug() << it.value() << QString::number(it.key() * 100)+QChar('%');
         }
     }
+
     // We may want to return the map itself, or a list with pairs id - percentage
     return bestMatches.values();
 }
 
 /// This method is the core functionality: It assigns a score to every image in the db
-QMap<qlonglong, double> HaarIface::searchDatabase(Haar::SignatureData *querySig, SketchType type)
+QMap<qlonglong, double> HaarIface::searchDatabase(Haar::SignatureData* querySig, SketchType type)
 {
     d->createWeightBin();
 
@@ -449,7 +581,7 @@ QMap<qlonglong, double> HaarIface::searchDatabase(Haar::SignatureData *querySig,
     queryMapY.fill(querySig->sig[0]);
     queryMapI.fill(querySig->sig[1]);
     queryMapQ.fill(querySig->sig[2]);
-    Haar::SignatureMap *queryMaps[3] = { &queryMapY, &queryMapI, &queryMapQ };
+    Haar::SignatureMap* queryMaps[3] = { &queryMapY, &queryMapI, &queryMapQ };
 
     // Map imageid -> score. Lowest score is best.
     // any newly inserted value will be initialized with a score of 0, as required
@@ -457,84 +589,92 @@ QMap<qlonglong, double> HaarIface::searchDatabase(Haar::SignatureData *querySig,
 
     // Variables for data read from DB
     DatabaseAccess      access;
-    QSqlQuery           query;
     DatabaseBlob        blob;
     qlonglong           imageid;
     Haar::SignatureData targetSig;
 
     // reference for easier access
-    QMap<qlonglong, Haar::SignatureData> &sigMap = *d->sigMap;
+    SignatureCache& signatureCache = *d->signatureCache;
 
     bool filterByAlbumRoots = !d->albumRootsToSearch.isEmpty();
 
     // if no cache is used or the cache signature map is empty, query the database
-    if ( !d->useCachedSigs || (sigMap.isEmpty() && d->useCachedSigs) )
+    if ( !d->useSignatureCache || (signatureCache.isEmpty() && d->useSignatureCache) )
     {
+        QString queryText;
+
         if (filterByAlbumRoots)
-            query = access.backend()->prepareQuery(QString("SELECT M.imageid, Albums.albumRoot, M.matrix "
-                                                           " FROM ImageHaarMatrix AS M, Albums, Images "
-                                                           " WHERE Images.id=M.imageid "
-                                                           " AND Albums.id=Images.album "
-                                                           " AND Images.status=1; "));
+        {
+            queryText = d->signatureByAlbumRootsQuery;
+        }
         else
-            query = access.backend()->prepareQuery(QString("SELECT M.imageid, 0, M.matrix "
-                                                           " FROM ImageHaarMatrix AS M, Images "
-                                                           " WHERE Images.id=M.imageid "
-                                                           " AND Images.status=1; "));
+        {
+            queryText = d->signatureQuery;
+        }
+
+        SqlQuery query = access.backend()->prepareQuery(queryText);
+
         if (!access.backend()->exec(query))
+        {
             return scores;
+        }
 
         // We don't use DatabaseBackend's convenience calls, as the result set is large
         // and we try to avoid copying in a temporary QList<QVariant>
+        int albumRootId = 0;
+
         while (query.next())
         {
             imageid = query.value(0).toLongLong();
 
             if (filterByAlbumRoots)
             {
-                int albumRootId = query.value(1).toInt();
+                albumRootId = query.value(1).toInt();
+
                 if (!d->albumRootsToSearch.contains(albumRootId))
+                {
                     continue;
+                }
             }
 
             blob.read(query.value(2).toByteArray(), &targetSig);
 
-            if (d->useCachedSigs)
+            if (d->useSignatureCache)
             {
-                sigMap[imageid] = targetSig;
+                signatureCache[imageid] = targetSig;
             }
             else
             {
-                double              &score = scores[imageid];
-                Haar::SignatureData &qSig  = *querySig;
-                Haar::SignatureData &tSig  = targetSig;
+                double&              score = scores[imageid];
+                Haar::SignatureData& qSig  = *querySig;
+                Haar::SignatureData& tSig  = targetSig;
 
-                calculateScore(score, qSig, tSig, weights, queryMaps);
+                score = calculateScore(qSig, tSig, weights, queryMaps);
             }
         }
     }
     // read cached signature map if possible
     else
     {
-        foreach (const qlonglong &imageid, sigMap.keys())
+        foreach (const qlonglong& imageid, signatureCache.keys())
         {
-            double              &score = scores[imageid];
-            Haar::SignatureData &qSig  = *querySig;
-            Haar::SignatureData &tSig  = sigMap[imageid];
+            double& score              = scores[imageid];
+            Haar::SignatureData& qSig  = *querySig;
+            Haar::SignatureData& tSig  = signatureCache[imageid];
 
-            calculateScore(score, qSig, tSig, weights, queryMaps);
+            score = calculateScore(qSig, tSig, weights, queryMaps);
         }
     }
 
-
     return scores;
 }
 
-QImage HaarIface::loadQImage(const QString &filename)
+QImage HaarIface::loadQImage(const QString& filename)
 {
     // NOTE: Can be optimized using DImg.
 
     QImage image;
+
     if (isJpegImage(filename))
     {
         // use fast jpeg loading
@@ -542,27 +682,33 @@ QImage HaarIface::loadQImage(const QString &filename)
         {
             // try QT now.
             if (!image.load(filename))
+            {
                 return QImage();
+            }
         }
     }
     else
     {
         // use default QT image loading
         if (!image.load(filename))
+        {
             return QImage();
+        }
     }
 
     return image;
 }
 
-bool HaarIface::retrieveSignatureFromDB(qlonglong imageid, Haar::SignatureData *sig)
+bool HaarIface::retrieveSignatureFromDB(qlonglong imageid, Haar::SignatureData* sig)
 {
     QList<QVariant> values;
     DatabaseAccess().backend()->execSql(QString("SELECT matrix FROM ImageHaarMatrix WHERE imageid=?"),
                                         imageid, &values);
 
     if (values.isEmpty())
+    {
         return false;
+    }
 
     DatabaseBlob blob;
 
@@ -570,15 +716,15 @@ bool HaarIface::retrieveSignatureFromDB(qlonglong imageid, Haar::SignatureData *
     return true;
 }
 
-void HaarIface::getBestAndWorstPossibleScore(Haar::SignatureData *sig, SketchType type,
-                                             double *lowestAndBestScore, double *highestAndWorstScore)
+void HaarIface::getBestAndWorstPossibleScore(Haar::SignatureData* sig, SketchType type,
+        double* lowestAndBestScore, double* highestAndWorstScore)
 {
     Haar::Weights weights((Haar::Weights::SketchType)type);
     double score = 0;
 
     // In the first step, the score is initialized with the weighted color channel averages.
     // We don't know the target channel average here, we only now its not negative => assume 0
-    for (int channel=0; channel<3; channel++)
+    for (int channel=0; channel<3; ++channel)
     {
         score += weights.weightForAverage(channel) * fabs( sig->avg[channel] /*- targetSig.avg[channel]*/ );
     }
@@ -590,10 +736,12 @@ void HaarIface::getBestAndWorstPossibleScore(Haar::SignatureData *sig, SketchTyp
     // In the second step, for every coefficient in the sig that have query and target in common,
     // so in our case all 3*40, subtract the specifically assigned weighting.
     score = 0;
-    for (int channel=0; channel<3; channel++)
+
+    for (int channel=0; channel<3; ++channel)
     {
-        Haar::Idx *coefs = sig->sig[channel];
-        for (int coef = 0; coef < Haar::NumberOfCoefficients; coef++)
+        Haar::Idx* coefs = sig->sig[channel];
+
+        for (int coef = 0; coef < Haar::NumberOfCoefficients; ++coef)
         {
             score -= weights.weight(d->bin->binAbs(coefs[coef]), channel);
         }
@@ -602,14 +750,17 @@ void HaarIface::getBestAndWorstPossibleScore(Haar::SignatureData *sig, SketchTyp
     *lowestAndBestScore = score;
 }
 
-void HaarIface::rebuildDuplicatesAlbums(const QList<int> &albums2Scan, double requiredPercentage,
-                                        HaarProgressObserver *observer)
+void HaarIface::rebuildDuplicatesAlbums(const QList<int>& albums2Scan, const QList<int>& tags2Scan,
+                                        double requiredPercentage, HaarProgressObserver* observer)
 {
     // Carry out search. This takes long.
-    QMap< qlonglong, QList<qlonglong> > results = findDuplicatesInAlbums(albums2Scan, requiredPercentage, observer);
+    QMap< qlonglong, QList<qlonglong> > results = findDuplicatesInAlbumsAndTags(albums2Scan,
+            tags2Scan,
+            requiredPercentage, observer);
 
     // Build search XML from the results. Store list of ids of similar images.
     QMap<QString, QString> queries;
+
     for (QMap< qlonglong, QList<qlonglong> >::const_iterator it = results.constBegin(); it != results.constEnd(); ++it)
     {
         SearchXmlWriter writer;
@@ -632,34 +783,53 @@ void HaarIface::rebuildDuplicatesAlbums(const QList<int> &albums2Scan, double re
         access.db()->deleteSearches(DatabaseSearch::DuplicatesSearch);
 
         // create new groups
-        for(QMap<QString, QString>::iterator it = queries.begin(); it != queries.end(); ++it)
+        for (QMap<QString, QString>::const_iterator it = queries.constBegin(); it != queries.constEnd(); ++it)
         {
             access.db()->addSearch(DatabaseSearch::DuplicatesSearch, it.key(), it.value());
         }
     }
 }
 
-
-QMap< qlonglong, QList<qlonglong> > HaarIface::findDuplicatesInAlbums(const QList<int> &albums2Scan,
-                                               double requiredPercentage, HaarProgressObserver *observer)
+QMap< qlonglong, QList<qlonglong> > HaarIface::findDuplicatesInAlbums(const QList<int>& albums2Scan,
+        double requiredPercentage, HaarProgressObserver* observer)
 {
-    QList<qlonglong> idList;
+    QSet<qlonglong> idList;
 
     // Get all items DB id from all albums and all collections
     foreach(int albumId, albums2Scan)
     {
-        idList << DatabaseAccess().db()->getItemIDsInAlbum(albumId);
+        idList.unite(DatabaseAccess().db()->getItemIDsInAlbum(albumId).toSet());
     }
 
     return findDuplicates(idList, requiredPercentage, observer);
 }
 
-QMap< qlonglong, QList<qlonglong> > HaarIface::findDuplicates(const QList<qlonglong>& images2Scan,
-                                               double requiredPercentage, HaarProgressObserver *observer)
+QMap< qlonglong, QList<qlonglong> > HaarIface::findDuplicatesInAlbumsAndTags(const QList<int>& albums2Scan,
+        const QList<int>& tags2Scan,
+        double requiredPercentage, HaarProgressObserver* observer)
+{
+    QSet<qlonglong> idList;
+
+    // Get all items DB id from all albums and all collections
+    foreach(int albumId, albums2Scan)
+    {
+        idList.unite(DatabaseAccess().db()->getItemIDsInAlbum(albumId).toSet());
+    }
+
+    // Get all items DB id from all tags
+    foreach(int albumId, tags2Scan)
+    {
+        idList.unite(DatabaseAccess().db()->getItemIDsInTag(albumId).toSet());
+    }
+
+    return findDuplicates(idList, requiredPercentage, observer);
+}
+
+QMap< qlonglong, QList<qlonglong> > HaarIface::findDuplicates(const QSet<qlonglong>& images2Scan,
+        double requiredPercentage, HaarProgressObserver* observer)
 {
     QMap< qlonglong, QList<qlonglong> >  resultsMap;
-    QList<qlonglong>::const_iterator     it;
-    QList<qlonglong>::const_iterator     it2;
+    QSet<qlonglong>::const_iterator      it;
     QList<qlonglong>                     list;
     QSet<qlonglong>                      resultsCandidates;
 
@@ -675,7 +845,7 @@ QMap< qlonglong, QList<qlonglong> > HaarIface::findDuplicates(const QList<qlongl
     }
 
     // create signature cache map for fast lookup
-    d->enableCachedSignatures(true);
+    d->setSignatureCacheEnabled(true, images2Scan);
 
     for (it = images2Scan.constBegin(); it != images2Scan.constEnd(); ++it)
     {
@@ -684,6 +854,7 @@ QMap< qlonglong, QList<qlonglong> > HaarIface::findDuplicates(const QList<qlongl
             //list = bestMatchesForImage(*it, 20, ScannedSketch);
             // find images with at least 90% similarity
             list = bestMatchesForImageWithThreshold(*it, requiredPercentage, ScannedSketch);
+
             if (!list.isEmpty())
             {
                 // the list will usually contain one image: the original. Filter out.
@@ -692,141 +863,78 @@ QMap< qlonglong, QList<qlonglong> > HaarIface::findDuplicates(const QList<qlongl
                     resultsMap.insert(*it, list);
                     resultsCandidates << *it;
 
-                    foreach (const qlonglong &id, list)
+                    foreach (const qlonglong& id, list)
                     {
                         resultsCandidates << id;
                     }
                 }
             }
         }
+
         // if an imageid is not a results candidate, remove it from the cached signature map as well,
         // to greatly improve speed
         if (!resultsCandidates.contains(*it))
-            d->sigMap->remove(*it);
+        {
+            d->signatureCache->remove(*it);
+        }
 
-        progress++;
+        ++progress;
 
-        if (observer && (progress == total || progress % progressStep == 0) )
+        if (observer && (progress == total || progress % progressStep == 0))
         {
             observer->processedNumber(progress);
         }
     }
 
-    d->enableCachedSignatures(false);
-
-    return resultsMap;
-}
-
-QMap< qlonglong, QList<qlonglong> > HaarIface::findDuplicatesFast(HaarProgressObserver *observer)
-{
-    QMap<qlonglong, QList<qlonglong> > resultsMap;
-    QList<QByteArray> matrixList;
-    int _total        = 0;
-    int total         = 0;
-    int progress      = 0;
-    int progressStep  = 20;
-
-    DatabaseAccess access;
-
-    /*
-     * Step 1: get all fingerprints that are absolutely identical
-     */
-    QSqlQuery mainQuery = access.backend()->prepareQuery(QString(
-                                                         "SELECT COUNT(*)AS x, ImageHaarMatrix.matrix "
-                                                         "FROM ImageHaarMatrix, Images "
-                                                         "WHERE Images.id=ImageHaarMatrix.imageid "
-                                                         "AND Images.status=1 "
-                                                         "GROUP BY ImageHaarMatrix.matrix HAVING x>1 ")
-    );
-
-    if (!access.backend()->exec(mainQuery))
-        return resultsMap;
-
-    // get all duplicate fingerprints and calculate total images
-    while (mainQuery.next())
-    {
-        matrixList << mainQuery.value(1).toByteArray();
-        _total += mainQuery.value(0).toInt();
-    }
-
-    // --------------------------------------------------------
-
+    // make sure the progress bar is really set to 100% when search is finished
     if (observer)
     {
-        total        = _total;
-        progressStep = qMax(progressStep, total / 100);
-        observer->totalNumberToScan(total);
-    }
-
-    // --------------------------------------------------------
-
-    /*
-     * Step 2: get all image ids for each duplicate fingerprint
-     */
-    QList<qlonglong> ids;
-    foreach(const QByteArray &matrix, matrixList)
-    {
-        QSqlQuery imageQuery = access.backend()->prepareQuery(QString(
-                "SELECT Images.id "
-                "FROM Images, ImageHaarMatrix "
-                "WHERE Images.id=ImageHaarMatrix.imageid "
-                "AND Images.status=1 "
-                "AND ImageHaarMatrix.matrix=?; ")
-        );
-        imageQuery.bindValue(0, matrix);
-        access.backend()->exec(imageQuery);
-
-        ids.clear();
-
-        while (imageQuery.next())
-        {
-            ids << imageQuery.value(0).toLongLong();
-            ++progress;
-        }
-        resultsMap[ids.first()] = ids;
-
-        if (observer && (progress % progressStep == 0))
-            observer->processedNumber(progress);
-    }
-
-    // make sure that the progress bar is really set to maximum now, just in case
-    // we have calculated a wrong amount of duplicate images
-    if (observer)
         observer->processedNumber(total);
+    }
+
+    // disable cache
+    d->setSignatureCacheEnabled(false);
 
     return resultsMap;
 }
 
-void HaarIface::calculateScore(double &score, Haar::SignatureData &querySig, Haar::SignatureData &targetSig,
-                           Haar::Weights &weights, Haar::SignatureMap** queryMaps)
+double HaarIface::calculateScore(Haar::SignatureData& querySig, Haar::SignatureData& targetSig,
+                                 Haar::Weights& weights, Haar::SignatureMap** queryMaps)
 {
-    // this is a reference
-//    double &score                  = scores[imageid];
-//    Haar::SignatureData &targetSig = sigMap[imageid];
+    double score = 0.0;
 
     // Step 1: Initialize scores with average intensity values of all three channels
-    for (int channel=0; channel<3; channel++)
+    for (int channel = 0; channel < 3; ++channel)
     {
         score += weights.weightForAverage(channel) * fabs( querySig.avg[channel] - targetSig.avg[channel] );
     }
 
     // Step 2: Decrease the score if query and target have significant coefficients in common
-    for (int channel=0; channel<3; channel++)
+    Haar::Idx* sig               = 0;
+    Haar::SignatureMap* queryMap = 0;
+    int x                        = 0;
+
+    for (int channel = 0; channel < 3; ++channel)
     {
-        Haar::Idx *sig               = targetSig.sig[channel];
-        Haar::SignatureMap *queryMap = queryMaps[channel];
-        int x;
-        for (int coef = 0; coef < Haar::NumberOfCoefficients; coef++)
+        sig      = targetSig.sig[channel];
+        queryMap = queryMaps[channel];
+
+        for (int coef = 0; coef < Haar::NumberOfCoefficients; ++coef)
         {
             // x is a pixel index, either positive or negative, 0..16384
             x = sig[coef];
+
             // If x is a significant coefficient with the same sign in the query signature as well,
             // decrease the score (lower is better)
             // Note: both method calls called with x accept positive or negative values
             if ((*queryMap)[x])
+            {
                 score -= weights.weight(d->bin->binAbs(x), channel);
+            }
         }
     }
+
+    return score;
 }
 
 }  // namespace Digikam
