@@ -51,10 +51,7 @@
 
 #include <libkdcraw/rnuminput.h>
 #include <libkdcraw/rcombobox.h>
-
-// Local includes
-
-#include "rexpanderbox.h"
+#include <libkdcraw/rexpanderbox.h>
 
 using namespace KDcrawIface;
 
@@ -66,18 +63,6 @@ class BorderSettingsPriv
 public:
 
     BorderSettingsPriv() :
-        configBorderTypeEntry("Border Type"),
-        configBorderPercentEntry("Border Percent"),
-        configBorderWidthEntry("Border Width"),
-        configPreserveAspectRatioEntry("Preserve Aspect Ratio"),
-        configSolidColorEntry("Solid Color"),
-        configNiepceBorderColorEntry("Niepce Border Color"),
-        configNiepceLineColorEntry("Niepce Line Color"),
-        configBevelUpperLeftColorEntry("Bevel Upper Left Color"),
-        configBevelLowerRightColorEntry("Bevel Lower Right Color"),
-        configDecorativeFirstColorEntry("Decorative First Color"),
-        configDecorativeSecondColorEntry("Decorative Second Color"),
-
         preserveAspectRatio(0),
         labelBackground(0),
         labelBorderPercent(0),
@@ -88,46 +73,59 @@ public:
         borderType(0),
         borderPercent(0),
         borderWidth(0)
-        {}
+    {}
 
-    const QString       configBorderTypeEntry;
-    const QString       configBorderPercentEntry;
-    const QString       configBorderWidthEntry;
-    const QString       configPreserveAspectRatioEntry;
-    const QString       configSolidColorEntry;
-    const QString       configNiepceBorderColorEntry;
-    const QString       configNiepceLineColorEntry;
-    const QString       configBevelUpperLeftColorEntry;
-    const QString       configBevelLowerRightColorEntry;
-    const QString       configDecorativeFirstColorEntry;
-    const QString       configDecorativeSecondColorEntry;
+    static const QString configBorderTypeEntry;
+    static const QString configBorderPercentEntry;
+    static const QString configBorderWidthEntry;
+    static const QString configPreserveAspectRatioEntry;
+    static const QString configSolidColorEntry;
+    static const QString configNiepceBorderColorEntry;
+    static const QString configNiepceLineColorEntry;
+    static const QString configBevelUpperLeftColorEntry;
+    static const QString configBevelLowerRightColorEntry;
+    static const QString configDecorativeFirstColorEntry;
+    static const QString configDecorativeSecondColorEntry;
 
-    QCheckBox*          preserveAspectRatio;
+    QCheckBox*           preserveAspectRatio;
 
-    QLabel*             labelBackground;
-    QLabel*             labelBorderPercent;
-    QLabel*             labelBorderWidth;
-    QLabel*             labelForeground;
+    QLabel*              labelBackground;
+    QLabel*              labelBorderPercent;
+    QLabel*              labelBorderWidth;
+    QLabel*              labelForeground;
 
-    QColor              bevelLowerRightColor;
-    QColor              bevelUpperLeftColor;
-    QColor              decorativeFirstColor;
-    QColor              decorativeSecondColor;
-    QColor              niepceBorderColor;
-    QColor              niepceLineColor;
-    QColor              solidColor;
+    QColor               bevelLowerRightColor;
+    QColor               bevelUpperLeftColor;
+    QColor               decorativeFirstColor;
+    QColor               decorativeSecondColor;
+    QColor               niepceBorderColor;
+    QColor               niepceLineColor;
+    QColor               solidColor;
 
-    KColorButton*       firstColorButton;
-    KColorButton*       secondColorButton;
+    KColorButton*        firstColorButton;
+    KColorButton*        secondColorButton;
 
-    RComboBox*          borderType;
-    RIntNumInput*       borderPercent;
-    RIntNumInput*       borderWidth;
+    RComboBox*           borderType;
+    RIntNumInput*        borderPercent;
+    RIntNumInput*        borderWidth;
 };
+const QString BorderSettingsPriv::configBorderTypeEntry("Border Type");
+const QString BorderSettingsPriv::configBorderPercentEntry("Border Percent");
+const QString BorderSettingsPriv::configBorderWidthEntry("Border Width");
+const QString BorderSettingsPriv::configPreserveAspectRatioEntry("Preserve Aspect Ratio");
+const QString BorderSettingsPriv::configSolidColorEntry("Solid Color");
+const QString BorderSettingsPriv::configNiepceBorderColorEntry("Niepce Border Color");
+const QString BorderSettingsPriv::configNiepceLineColorEntry("Niepce Line Color");
+const QString BorderSettingsPriv::configBevelUpperLeftColorEntry("Bevel Upper Left Color");
+const QString BorderSettingsPriv::configBevelLowerRightColorEntry("Bevel Lower Right Color");
+const QString BorderSettingsPriv::configDecorativeFirstColorEntry("Decorative First Color");
+const QString BorderSettingsPriv::configDecorativeSecondColorEntry("Decorative Second Color");
+
+// --------------------------------------------------------
 
 BorderSettings::BorderSettings(QWidget* parent)
-              : QWidget(parent),
-             d(new BorderSettingsPriv)
+    : QWidget(parent),
+      d(new BorderSettingsPriv)
 {
     QGridLayout* grid = new QGridLayout(parent);
 
@@ -163,9 +161,9 @@ BorderSettings::BorderSettings(QWidget* parent)
     d->preserveAspectRatio = new QCheckBox();
     d->preserveAspectRatio->setText(i18n("Preserve Aspect Ratio"));
     d->preserveAspectRatio->setWhatsThis(i18n("Enable this option if you want to preserve the aspect "
-                                              "ratio of image. If enabled, the border width will be "
-                                              "a percentage of the image size, else the border width will be "
-                                              "in pixels."));
+                                         "ratio of image. If enabled, the border width will be "
+                                         "a percentage of the image size, else the border width will be "
+                                         "in pixels."));
 
     d->labelBorderPercent  = new QLabel(i18n("Width (%):"));
     d->borderPercent       = new RIntNumInput();
@@ -265,7 +263,7 @@ void BorderSettings::setSettings(const BorderContainer& settings)
     d->preserveAspectRatio->setChecked(settings.preserveAspectRatio);
     d->borderType->setCurrentIndex(settings.borderType);
     d->borderWidth->setValue(settings.borderWidth1);
-    d->borderPercent->setValue(settings.borderPercent * 100.0);
+    d->borderPercent->setValue((int)(settings.borderPercent * 100.0));
 
     d->solidColor            = settings.solidColor;
     d->niepceBorderColor     = settings.niepceBorderColor;
@@ -477,73 +475,73 @@ QString BorderSettings::getBorderPath(int border)
 
     switch (border)
     {
-       case BorderContainer::PineBorder:
-          pattern = "pine-pattern";
-          break;
+        case BorderContainer::PineBorder:
+            pattern = "pine-pattern";
+            break;
 
-       case BorderContainer::WoodBorder:
-          pattern = "wood-pattern";
-          break;
+        case BorderContainer::WoodBorder:
+            pattern = "wood-pattern";
+            break;
 
-       case BorderContainer::PaperBorder:
-          pattern = "paper-pattern";
-          break;
+        case BorderContainer::PaperBorder:
+            pattern = "paper-pattern";
+            break;
 
-       case BorderContainer::ParqueBorder:
-          pattern = "parque-pattern";
-          break;
+        case BorderContainer::ParqueBorder:
+            pattern = "parque-pattern";
+            break;
 
-       case BorderContainer::IceBorder:
-          pattern = "ice-pattern";
-          break;
+        case BorderContainer::IceBorder:
+            pattern = "ice-pattern";
+            break;
 
-       case BorderContainer::LeafBorder:
-          pattern = "leaf-pattern";
-          break;
+        case BorderContainer::LeafBorder:
+            pattern = "leaf-pattern";
+            break;
 
-       case BorderContainer::MarbleBorder:
-          pattern = "marble-pattern";
-          break;
+        case BorderContainer::MarbleBorder:
+            pattern = "marble-pattern";
+            break;
 
-       case BorderContainer::RainBorder:
-          pattern = "rain-pattern";
-          break;
+        case BorderContainer::RainBorder:
+            pattern = "rain-pattern";
+            break;
 
-       case BorderContainer::CratersBorder:
-          pattern = "craters-pattern";
-          break;
+        case BorderContainer::CratersBorder:
+            pattern = "craters-pattern";
+            break;
 
-       case BorderContainer::DriedBorder:
-          pattern = "dried-pattern";
-          break;
+        case BorderContainer::DriedBorder:
+            pattern = "dried-pattern";
+            break;
 
-       case BorderContainer::PinkBorder:
-          pattern = "pink-pattern";
-          break;
+        case BorderContainer::PinkBorder:
+            pattern = "pink-pattern";
+            break;
 
-       case BorderContainer::StoneBorder:
-          pattern = "stone-pattern";
-          break;
+        case BorderContainer::StoneBorder:
+            pattern = "stone-pattern";
+            break;
 
-       case BorderContainer::ChalkBorder:
-          pattern = "chalk-pattern";
-          break;
+        case BorderContainer::ChalkBorder:
+            pattern = "chalk-pattern";
+            break;
 
-       case BorderContainer::GraniteBorder:
-          pattern = "granit-pattern";
-          break;
+        case BorderContainer::GraniteBorder:
+            pattern = "granit-pattern";
+            break;
 
-       case BorderContainer::RockBorder:
-          pattern = "rock-pattern";
-          break;
+        case BorderContainer::RockBorder:
+            pattern = "rock-pattern";
+            break;
 
-       case BorderContainer::WallBorder:
-          pattern = "wall-pattern";
-          break;
+        case BorderContainer::WallBorder:
+            pattern = "wall-pattern";
+            break;
 
-       default:
-          return pattern;
-          break;
+        default:
+            return pattern;
+            break;
     }
 
     return (KStandardDirs::locate("data", QString("digikam/data/") + pattern + QString(".png")));
