@@ -6,7 +6,7 @@
  * Date        : 2006-01-10
  * Description : a widget to display CIE tongue from an ICC profile.
  *
- * Copyright (C) 2006-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * Any source code are inspired from lprof project and
  * Copyright (C) 1998-2001 Marti Maria
@@ -53,158 +53,163 @@
 namespace Digikam
 {
 
-    /**
-    The following table gives the CIE  color matching functions
-    \f$\bar{x}(\lambda)\f$, \f$\bar{y}(\lambda)\f$, and
-    \f$\bar{z}(\lambda)\f$, for wavelengths \f$\lambda\f$ at 5 nanometer
-    increments from 380 nm through 780 nm. This table is used in conjunction
-    with Planck's law for the energy spectrum of a black body at a given
-    temperature to plot the black body curve on the CIE chart.
+/**
+The following table gives the CIE  color matching functions
+\f$\bar{x}(\lambda)\f$, \f$\bar{y}(\lambda)\f$, and
+\f$\bar{z}(\lambda)\f$, for wavelengths \f$\lambda\f$ at 5 nanometer
+increments from 380 nm through 780 nm. This table is used in conjunction
+with Planck's law for the energy spectrum of a black body at a given
+temperature to plot the black body curve on the CIE chart.
 
-    The following table gives the spectral chromaticity co-ordinates
-    \f$x(\lambda)\f$ and \f$y(\lambda)\f$ for wavelengths in 5 nanometer
-    increments from 380 nm through 780 nm. These coordinates represent the
-    position in the CIE x-y space of pure spectral colors of the given
-    wavelength, and thus define the outline of the CIE "tongue" diagram.
-    */
-    static const double spectral_chromaticity[81][3] =
-    {
-        { 0.1741, 0.0050 },               // 380 nm
-        { 0.1740, 0.0050 },
-        { 0.1738, 0.0049 },
-        { 0.1736, 0.0049 },
-        { 0.1733, 0.0048 },
-        { 0.1730, 0.0048 },
-        { 0.1726, 0.0048 },
-        { 0.1721, 0.0048 },
-        { 0.1714, 0.0051 },
-        { 0.1703, 0.0058 },
-        { 0.1689, 0.0069 },
-        { 0.1669, 0.0086 },
-        { 0.1644, 0.0109 },
-        { 0.1611, 0.0138 },
-        { 0.1566, 0.0177 },
-        { 0.1510, 0.0227 },
-        { 0.1440, 0.0297 },
-        { 0.1355, 0.0399 },
-        { 0.1241, 0.0578 },
-        { 0.1096, 0.0868 },
-        { 0.0913, 0.1327 },
-        { 0.0687, 0.2007 },
-        { 0.0454, 0.2950 },
-        { 0.0235, 0.4127 },
-        { 0.0082, 0.5384 },
-        { 0.0039, 0.6548 },
-        { 0.0139, 0.7502 },
-        { 0.0389, 0.8120 },
-        { 0.0743, 0.8338 },
-        { 0.1142, 0.8262 },
-        { 0.1547, 0.8059 },
-        { 0.1929, 0.7816 },
-        { 0.2296, 0.7543 },
-        { 0.2658, 0.7243 },
-        { 0.3016, 0.6923 },
-        { 0.3373, 0.6589 },
-        { 0.3731, 0.6245 },
-        { 0.4087, 0.5896 },
-        { 0.4441, 0.5547 },
-        { 0.4788, 0.5202 },
-        { 0.5125, 0.4866 },
-        { 0.5448, 0.4544 },
-        { 0.5752, 0.4242 },
-        { 0.6029, 0.3965 },
-        { 0.6270, 0.3725 },
-        { 0.6482, 0.3514 },
-        { 0.6658, 0.3340 },
-        { 0.6801, 0.3197 },
-        { 0.6915, 0.3083 },
-        { 0.7006, 0.2993 },
-        { 0.7079, 0.2920 },
-        { 0.7140, 0.2859 },
-        { 0.7190, 0.2809 },
-        { 0.7230, 0.2770 },
-        { 0.7260, 0.2740 },
-        { 0.7283, 0.2717 },
-        { 0.7300, 0.2700 },
-        { 0.7311, 0.2689 },
-        { 0.7320, 0.2680 },
-        { 0.7327, 0.2673 },
-        { 0.7334, 0.2666 },
-        { 0.7340, 0.2660 },
-        { 0.7344, 0.2656 },
-        { 0.7346, 0.2654 },
-        { 0.7347, 0.2653 },
-        { 0.7347, 0.2653 },
-        { 0.7347, 0.2653 },
-        { 0.7347, 0.2653 },
-        { 0.7347, 0.2653 },
-        { 0.7347, 0.2653 },
-        { 0.7347, 0.2653 },
-        { 0.7347, 0.2653 },
-        { 0.7347, 0.2653 },
-        { 0.7347, 0.2653 },
-        { 0.7347, 0.2653 },
-        { 0.7347, 0.2653 },
-        { 0.7347, 0.2653 },
-        { 0.7347, 0.2653 },
-        { 0.7347, 0.2653 },
-        { 0.7347, 0.2653 },
-        { 0.7347, 0.2653 }  // 780 nm
-    };
+The following table gives the spectral chromaticity co-ordinates
+\f$x(\lambda)\f$ and \f$y(\lambda)\f$ for wavelengths in 5 nanometer
+increments from 380 nm through 780 nm. These coordinates represent the
+position in the CIE x-y space of pure spectral colors of the given
+wavelength, and thus define the outline of the CIE "tongue" diagram.
+*/
+static const double spectral_chromaticity[81][3] =
+{
+    { 0.1741, 0.0050 },               // 380 nm
+    { 0.1740, 0.0050 },
+    { 0.1738, 0.0049 },
+    { 0.1736, 0.0049 },
+    { 0.1733, 0.0048 },
+    { 0.1730, 0.0048 },
+    { 0.1726, 0.0048 },
+    { 0.1721, 0.0048 },
+    { 0.1714, 0.0051 },
+    { 0.1703, 0.0058 },
+    { 0.1689, 0.0069 },
+    { 0.1669, 0.0086 },
+    { 0.1644, 0.0109 },
+    { 0.1611, 0.0138 },
+    { 0.1566, 0.0177 },
+    { 0.1510, 0.0227 },
+    { 0.1440, 0.0297 },
+    { 0.1355, 0.0399 },
+    { 0.1241, 0.0578 },
+    { 0.1096, 0.0868 },
+    { 0.0913, 0.1327 },
+    { 0.0687, 0.2007 },
+    { 0.0454, 0.2950 },
+    { 0.0235, 0.4127 },
+    { 0.0082, 0.5384 },
+    { 0.0039, 0.6548 },
+    { 0.0139, 0.7502 },
+    { 0.0389, 0.8120 },
+    { 0.0743, 0.8338 },
+    { 0.1142, 0.8262 },
+    { 0.1547, 0.8059 },
+    { 0.1929, 0.7816 },
+    { 0.2296, 0.7543 },
+    { 0.2658, 0.7243 },
+    { 0.3016, 0.6923 },
+    { 0.3373, 0.6589 },
+    { 0.3731, 0.6245 },
+    { 0.4087, 0.5896 },
+    { 0.4441, 0.5547 },
+    { 0.4788, 0.5202 },
+    { 0.5125, 0.4866 },
+    { 0.5448, 0.4544 },
+    { 0.5752, 0.4242 },
+    { 0.6029, 0.3965 },
+    { 0.6270, 0.3725 },
+    { 0.6482, 0.3514 },
+    { 0.6658, 0.3340 },
+    { 0.6801, 0.3197 },
+    { 0.6915, 0.3083 },
+    { 0.7006, 0.2993 },
+    { 0.7079, 0.2920 },
+    { 0.7140, 0.2859 },
+    { 0.7190, 0.2809 },
+    { 0.7230, 0.2770 },
+    { 0.7260, 0.2740 },
+    { 0.7283, 0.2717 },
+    { 0.7300, 0.2700 },
+    { 0.7311, 0.2689 },
+    { 0.7320, 0.2680 },
+    { 0.7327, 0.2673 },
+    { 0.7334, 0.2666 },
+    { 0.7340, 0.2660 },
+    { 0.7344, 0.2656 },
+    { 0.7346, 0.2654 },
+    { 0.7347, 0.2653 },
+    { 0.7347, 0.2653 },
+    { 0.7347, 0.2653 },
+    { 0.7347, 0.2653 },
+    { 0.7347, 0.2653 },
+    { 0.7347, 0.2653 },
+    { 0.7347, 0.2653 },
+    { 0.7347, 0.2653 },
+    { 0.7347, 0.2653 },
+    { 0.7347, 0.2653 },
+    { 0.7347, 0.2653 },
+    { 0.7347, 0.2653 },
+    { 0.7347, 0.2653 },
+    { 0.7347, 0.2653 },
+    { 0.7347, 0.2653 },
+    { 0.7347, 0.2653 },
+    { 0.7347, 0.2653 }  // 780 nm
+};
 
-class CIETongueWidgetPriv
+class CIETongueWidget::CIETongueWidgetPriv
 {
 public:
 
-    CIETongueWidgetPriv()
+    CIETongueWidgetPriv() :
+        profileDataAvailable(true),
+        loadingImageMode(false),
+        loadingImageSucess(false),
+        needUpdatePixmap(false),
+        uncalibratedColor(false),
+        xBias(0),
+        yBias(0),
+        pxcols(0),
+        pxrows(0),
+        progressCount(0),
+        gridside(0),
+        progressTimer(0),
+        hMonitorProfile(0),
+        hXYZProfile(0),
+        hXFORM(0)
     {
-        profileDataAvailable = true;
-        loadingImageMode     = false;
-        loadingImageSucess   = false;
-        needUpdatePixmap     = false;
-        uncalibratedColor    = false;
-        hMonitorProfile      = 0;
-        hXYZProfile          = 0;
-        hXFORM               = 0;
-        Measurement.Patches  = 0;
-        Measurement.Allowed  = 0;
-        progressCount        = 0;
-        progressTimer        = 0;
-        progressPix          = SmallIcon("process-working", 22);
+        progressPix = SmallIcon("process-working", 22);
+        Measurement.Patches = 0;
+        Measurement.Allowed = 0;
     }
 
-    bool             profileDataAvailable;
-    bool             loadingImageMode;
-    bool             loadingImageSucess;
-    bool             needUpdatePixmap;
-    bool             uncalibratedColor;
+    bool            profileDataAvailable;
+    bool            loadingImageMode;
+    bool            loadingImageSucess;
+    bool            needUpdatePixmap;
+    bool            uncalibratedColor;
 
-    int              xBias;
-    int              yBias;
-    int              pxcols;
-    int              pxrows;
-    int              progressCount;           // Position of animation during loading/calculation.
+    int             xBias;
+    int             yBias;
+    int             pxcols;
+    int             pxrows;
+    int             progressCount;           // Position of animation during loading/calculation.
 
-    double           gridside;
+    double          gridside;
 
-    QPainter         painter;
+    QPainter        painter;
 
-    QTimer          *progressTimer;
+    QTimer*         progressTimer;
 
-    QPixmap          pixmap;
-    QPixmap          progressPix;
+    QPixmap         pixmap;
+    QPixmap         progressPix;
 
-    cmsHPROFILE      hMonitorProfile;
-    cmsHPROFILE      hXYZProfile;
-    cmsHTRANSFORM    hXFORM;
-    cmsCIExyYTRIPLE  Primaries;
-    cmsCIEXYZ        MediaWhite;
+    cmsHPROFILE     hMonitorProfile;
+    cmsHPROFILE     hXYZProfile;
+    cmsHTRANSFORM   hXFORM;
+    cmsCIExyYTRIPLE Primaries;
+    cmsCIEXYZ       MediaWhite;
 
-    MEASUREMENT      Measurement;
+    MEASUREMENT     Measurement;
 };
 
-CIETongueWidget::CIETongueWidget(int w, int h, QWidget *parent, cmsHPROFILE hMonitor)
-               : QWidget(parent), d(new CIETongueWidgetPriv)
+CIETongueWidget::CIETongueWidget(int w, int h, QWidget* parent, cmsHPROFILE hMonitor)
+    : QWidget(parent), d(new CIETongueWidgetPriv)
 {
     d->progressTimer = new QTimer(this);
     setMinimumSize(w, h);
@@ -212,9 +217,13 @@ CIETongueWidget::CIETongueWidget(int w, int h, QWidget *parent, cmsHPROFILE hMon
     cmsErrorAction(LCMS_ERROR_SHOW);
 
     if (hMonitor)
+    {
         d->hMonitorProfile = hMonitor;
+    }
     else
+    {
         d->hMonitorProfile = cmsCreate_sRGBProfile();
+    }
 
     d->hXYZProfile = cmsCreateXYZProfile();
     d->hXFORM      = cmsCreateTransform(d->hXYZProfile, TYPE_XYZ_16,
@@ -228,10 +237,14 @@ CIETongueWidget::CIETongueWidget(int w, int h, QWidget *parent, cmsHPROFILE hMon
 CIETongueWidget::~CIETongueWidget()
 {
     if (d->Measurement.Patches)
+    {
         free(d->Measurement.Patches);
+    }
 
     if (d->Measurement.Allowed)
+    {
         free(d->Measurement.Allowed);
+    }
 
     cmsDeleteTransform(d->hXFORM);
     cmsCloseProfile(d->hXYZProfile);
@@ -305,7 +318,7 @@ bool CIETongueWidget::setProfileFromFile(const KUrl& file)
         d->loadingImageSucess   = false;
     }
 
-    d->loadingImageMode = false;
+    d->loadingImageMode  = false;
     d->uncalibratedColor = false;
 
     d->progressTimer->stop();
@@ -365,12 +378,13 @@ void CIETongueWidget::setProfile(cmsHPROFILE hProfile)
     // Get target data stored in profile
 
     ZeroMemory(&(d->Measurement), sizeof(MEASUREMENT));
-    char*  CharTarget;
-    size_t CharTargetSize;
+    char*  CharTarget     = 0;
+    size_t CharTargetSize = 0;
 
     if (cmsTakeCharTargetData(hProfile, &CharTarget, &CharTargetSize))
     {
         LCMSHANDLE hSheet = cmsxIT8LoadFromMem(CharTarget, CharTargetSize);
+
         if (hSheet != NULL)
         {
             cmsxPCollLoadFromSheet(&(d->Measurement),  hSheet);
@@ -428,7 +442,8 @@ void CIETongueWidget::outlineTongue()
         int ix = (x - 380) / 5;
 
         cmsCIExyY p = {spectral_chromaticity[ix][0],
-                       spectral_chromaticity[ix][1], 1};
+                       spectral_chromaticity[ix][1], 1
+                      };
 
         int icx, icy;
         mapPoint(icx, icy, &p);
@@ -445,14 +460,13 @@ void CIETongueWidget::outlineTongue()
 
         lx = icx;
         ly = icy;
-     }
+    }
 
     biasedLine(lx, ly, fx, fy);
 }
 
 void CIETongueWidget::fillTongue()
 {
-
     QImage Img = d->pixmap.toImage();
 
     int x;
@@ -562,7 +576,8 @@ void CIETongueWidget::drawLabels()
         int ix = (x - 380) / 5;
 
         cmsCIExyY p = {spectral_chromaticity[ix][0],
-                       spectral_chromaticity[ix][1], 1};
+                       spectral_chromaticity[ix][1], 1
+                      };
 
         int icx, icy;
         mapPoint(icx, icy, &p);
@@ -607,10 +622,14 @@ void CIETongueWidget::drawPatches()
             if (p->dwFlags & PATCH_HAS_XYZ_PROOF)
             {
                 if (p->XYZ.Y < 0.03)
-                   continue;
+                {
+                    continue;
+                }
 
                 if (p->XYZProof.Y < 0.03)
-                   continue;
+                {
+                    continue;
+                }
 
                 cmsCIExyY Pt;
                 cmsXYZ2xyY(&Pt, &p->XYZProof);
@@ -620,7 +639,9 @@ void CIETongueWidget::drawPatches()
                 mapPoint(icx2, icy2, &Pt);
 
                 if (icx2 < 5 || icy2 < 5 || icx1 < 5 || icy1 < 5)
+                {
                     continue;
+                }
 
                 d->painter.setPen(qRgb(255, 255, 0));
                 biasedLine(icx1, icy1, icx2, icy2);
@@ -657,7 +678,7 @@ void CIETongueWidget::sweep_sRGB()
     hsRGB = cmsCreate_sRGBProfile();
 
     cmsHTRANSFORM xform = cmsCreateTransform(hsRGB, TYPE_RGB_16, hXYZ, TYPE_XYZ_16,
-                                             INTENT_ABSOLUTE_COLORIMETRIC, cmsFLAGS_NOTPRECALC);
+                          INTENT_ABSOLUTE_COLORIMETRIC, cmsFLAGS_NOTPRECALC);
     WORD RGB[3], XYZ[3];
     cmsCIEXYZ xyz, MediaWhite;
     cmsCIExyY xyY, WhitePt;
@@ -672,7 +693,9 @@ void CIETongueWidget::sweep_sRGB()
         {
             for (b=0; b < 65536; b += 1024)
             {
-                RGB[0] = r; RGB[1] = g; RGB[2] = b;
+                RGB[0] = r;
+                RGB[1] = g;
+                RGB[2] = b;
                 cmsDoTransform(xform, RGB, XYZ, 1);
                 cmsXYZEncoded2Float(&xyz, XYZ);
                 cmsXYZ2xyY(&xyY, &xyz);
@@ -755,13 +778,19 @@ void CIETongueWidget::updatePixmap()
     drawTongueGrid();
 
     if (d->MediaWhite.Y > 0.0)
+    {
         drawWhitePoint();
+    }
 
     if (d->Primaries.Red.Y != 0.0)
+    {
         drawColorantTriangle();
+    }
 
     if (d->Measurement.Patches && d->Measurement.Allowed)
+    {
         drawPatches();
+    }
 
     d->painter.end();
 }
@@ -795,7 +824,11 @@ void CIETongueWidget::paintEvent(QPaintEvent*)
 
         QPixmap anim(d->progressPix.copy(0, d->progressCount*22, 22, 22));
         d->progressCount++;
-        if (d->progressCount == 8) d->progressCount = 0;
+
+        if (d->progressCount == 8)
+        {
+            d->progressCount = 0;
+        }
 
         // ... and we render busy text.
 
@@ -828,13 +861,13 @@ void CIETongueWidget::paintEvent(QPaintEvent*)
         if (d->uncalibratedColor)
         {
             p.drawText(0, 0, width(), height(), Qt::AlignCenter,
-                    i18n("Uncalibrated color space"));
+                       i18n("Uncalibrated color space"));
         }
         else
         {
             p.setPen(Qt::red);
             p.drawText(0, 0, width(), height(), Qt::AlignCenter,
-                    i18n("No profile available..."));
+                       i18n("No profile available..."));
         }
 
         return;
@@ -842,13 +875,15 @@ void CIETongueWidget::paintEvent(QPaintEvent*)
 
     // Create CIE tongue if needed
     if (d->needUpdatePixmap)
+    {
         updatePixmap();
+    }
 
     // draw prerendered tongue
     p.drawPixmap(0, 0, d->pixmap);
 }
 
-void CIETongueWidget::resizeEvent(QResizeEvent * event)
+void CIETongueWidget::resizeEvent(QResizeEvent* event)
 {
     Q_UNUSED(event);
     d->needUpdatePixmap = true;
