@@ -32,6 +32,7 @@
 #include <QGroupBox>
 #include <QLabel>
 #include <QSplitter>
+#include <QTreeWidget>
 #include <QVBoxLayout>
 
 // KDE includes
@@ -49,8 +50,6 @@
 // Local includes
 
 #include "albumsettings.h"
-#include "folderitem.h"
-#include "folderview.h"
 #include "imagepropertiestab.h"
 #include "theme.h"
 #include "themediconview.h"
@@ -63,24 +62,24 @@ class MainWindowPriv
 {
 public:
 
-    MainWindowPriv()
+    MainWindowPriv() :
+        bevelLabel(0),
+        gradientLabel(0),
+        begColorLabel(0),
+        endColorLabel(0),
+        borderColorLabel(0),
+        addBorderCheck(0),
+        propertyCombo(0),
+        bevelCombo(0),
+        gradientCombo(0),
+        endColorBtn(0),
+        begColorBtn(0),
+        borderColorBtn(0),
+        treeView(0),
+        iconView(0),
+        propView(0),
+        theme(0)
     {
-        bevelLabel       = 0;
-        gradientLabel    = 0;
-        begColorLabel    = 0;
-        endColorLabel    = 0;
-        borderColorLabel = 0;
-        propertyCombo    = 0;
-        bevelCombo       = 0;
-        gradientCombo    = 0;
-        addBorderCheck   = 0;
-        endColorBtn      = 0;
-        begColorBtn      = 0;
-        borderColorBtn   = 0;
-        folderView       = 0;
-        iconView         = 0;
-        propView         = 0;
-        theme            = 0;
     }
 
     QLabel*             bevelLabel;
@@ -104,14 +103,14 @@ public:
     KColorButton*       begColorBtn;
     KColorButton*       borderColorBtn;
 
-    FolderView*         folderView;
+    QTreeWidget*        treeView;
     ThemedIconView*     iconView;
     ImagePropertiesTab* propView;
     Theme*              theme;
 };
 
 MainWindow::MainWindow()
-          : KDialog(0), d(new MainWindowPriv)
+    : KDialog(0), d(new MainWindowPriv)
 {
     setWindowTitle(i18n("digiKam Theme Designer"));
     setAttribute(Qt::WA_DeleteOnClose);
@@ -142,13 +141,13 @@ MainWindow::MainWindow()
     splitter->setOrientation(Qt::Horizontal);
     splitter->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding));
 
-    d->folderView = new FolderView(splitter);
+    d->treeView   = new QTreeWidget(splitter);
     d->iconView   = new ThemedIconView(splitter);
     d->propView   = new ImagePropertiesTab(splitter);
 
     // Property Editor ---------------------------------------------
 
-    QGroupBox *groupBox = new QGroupBox(this);
+    QGroupBox* groupBox = new QGroupBox(this);
     QVBoxLayout* vlay   = new QVBoxLayout(groupBox);
 
     QLabel* label1   = new QLabel(i18n("Property: "), groupBox);
@@ -279,21 +278,27 @@ MainWindow::MainWindow()
 
     // ------------------------------------------------------------------------
 
-    d->folderView->addColumn("My Albums");
-    d->folderView->setResizeMode(Q3ListView::LastColumn);
-    d->folderView->setRootIsDecorated(true);
+    d->treeView->setColumnCount(1);
+    d->treeView->setHeaderLabel("My Albums");
+    d->treeView->setRootIsDecorated(true);
+
+    KIconLoader* iconLoader = KIconLoader::global();
+
+    QTreeWidgetItem* root = new QTreeWidgetItem(d->treeView, QStringList(QString("Album Root")));
+    root->setIcon(0, iconLoader->loadIcon("folder", KIconLoader::NoGroup, 32));
+    d->treeView->insertTopLevelItem(0, root);
+
+    QList<QTreeWidgetItem*> items;
 
-    KIconLoader *iconLoader = KIconLoader::global();
     for (int i=0; i<10; ++i)
     {
-        FolderItem* folderItem = new FolderItem(d->folderView, QString("Album %1").arg(i));
-        folderItem->setPixmap(0, iconLoader->loadIcon("folder", KIconLoader::NoGroup, 32));
-        if (i == 2)
-        {
-            d->folderView->setSelected(folderItem, true);
-        }
+        QTreeWidgetItem* item = new QTreeWidgetItem(root, QStringList(QString("Album %1").arg(i)));
+        item->setIcon(0, iconLoader->loadIcon("folder", KIconLoader::NoGroup, 32));
+        items.append(item);
     }
 
+    root->addChildren(items);
+
     // ------------------------------------------------------------------------
 
     slotPropertyChanged();
@@ -310,8 +315,11 @@ void MainWindow::slotLoad()
     KUrl themesUrl(KGlobal::dirs()->findResourceDir("themes", QString()));
 
     QString path = KFileDialog::getOpenFileName(themesUrl, QString(), this, QString());
+
     if (path.isEmpty())
+    {
         return;
+    }
 
     QFileInfo fi(path);
     d->theme->name     = fi.fileName();
@@ -325,10 +333,14 @@ void MainWindow::slotLoad()
 void MainWindow::slotSave()
 {
     QString path = KFileDialog::getSaveFileName(KUrl(), QString(), this, QString());
+
     if (path.isEmpty())
+    {
         return;
+    }
 
     QFile file(path);
+
     if (!file.open(QIODevice::WriteOnly))
     {
         KMessageBox::error(this, i18n("Failed to open file for writing"));
@@ -364,7 +376,7 @@ void MainWindow::slotPropertyChanged()
     d->borderColorBtn->setEnabled(false);
     d->borderColorLabel->setEnabled(false);
 
-    switch(d->propertyCombo->currentIndex())
+    switch (d->propertyCombo->currentIndex())
     {
         case(BASE):
         {
@@ -529,16 +541,21 @@ void MainWindow::slotPropertyChanged()
     };
 
     d->bevelCombo->blockSignals(false);
+
     d->gradientCombo->blockSignals(false);
+
     d->begColorBtn->blockSignals(false);
+
     d->endColorBtn->blockSignals(false);
+
     d->addBorderCheck->blockSignals(false);
+
     d->borderColorBtn->blockSignals(false);
 }
 
 void MainWindow::slotUpdateTheme()
 {
-    switch(d->propertyCombo->currentIndex())
+    switch (d->propertyCombo->currentIndex())
     {
         case(BASE):
         {
