@@ -32,10 +32,10 @@ namespace Digikam
 {
 
 TrimmedModifier::TrimmedModifier()
-               : Modifier(i18n("Trimmed"), i18n("Remove leading, trailing and extra whitespace"),
-                          SmallIcon("edit-cut"))
+    : Modifier(i18n("Trimmed"), i18n("Remove leading, trailing and extra whitespace"),
+               SmallIcon("edit-cut"))
 {
-    QString token = "{trim}";
+    QString token("{trim}");
     addToken(token, description());
 
     QRegExp reg(escapeToken(token));
@@ -43,10 +43,10 @@ TrimmedModifier::TrimmedModifier()
     setRegExp(reg);
 }
 
-QString TrimmedModifier::modifyOperation(const ParseSettings& settings, const QString& str2Modify)
+QString TrimmedModifier::parseOperation(ParseSettings& settings)
 {
     Q_UNUSED(settings);
-    return str2Modify.simplified();
+    return settings.str2Modify.simplified();
 }
 
 } // namespace Digikam
