@@ -7,8 +7,8 @@
  * Description : digital camera controller
  *
  * Copyright (C) 2004-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
- * Copyright (C) 2006-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
- * Copyright (C) 2006-2009 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
+ * Copyright (C) 2006-2010 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2006-2010 by Marcel Wiesweg <marcel dot wiesweg at gmx dot de>
  *
  * This program is free software; you can redistribute it
  * and/or modify it under the terms of the GNU General
@@ -99,47 +99,47 @@ public:
     QMap<QString,QVariant> map;
 };
 
-class CameraControllerPriv
+class CameraController::CameraControllerPriv
 {
 public:
 
-    CameraControllerPriv()
+    CameraControllerPriv() :
+        close(false),
+        overwriteAll(false),
+        skipAll(false),
+        canceled(false),
+        running(false),
+        downloadTotal(0),
+        parent(0),
+        timer(0),
+        camera(0)
     {
-        close         = false;
-        overwriteAll  = false;
-        skipAll       = false;
-        canceled      = false;
-        running       = false;
-        downloadTotal = 0;
-        parent        = 0;
-        timer         = 0;
-        camera        = 0;
     }
 
-    bool                    close;
-    bool                    overwriteAll;
-    bool                    skipAll;
-    bool                    canceled;
-    bool                    running;
+    bool                  close;
+    bool                  overwriteAll;
+    bool                  skipAll;
+    bool                  canceled;
+    bool                  running;
 
-    int                     downloadTotal;
+    int                   downloadTotal;
 
-    QWidget*                parent;
+    QWidget*              parent;
 
-    QTimer*                 timer;
+    QTimer*               timer;
 
-    DKCamera*               camera;
+    DKCamera*             camera;
 
-    QMutex                  mutex;
-    QWaitCondition          condVar;
+    QMutex                mutex;
+    QWaitCondition        condVar;
 
-    QList<CameraCommand*>   commands;
+    QList<CameraCommand*> commands;
 };
 
 CameraController::CameraController(QWidget* parent,
                                    const QString& title, const QString& model,
                                    const QString& port, const QString& path)
-                : QThread(parent), d(new CameraControllerPriv)
+    : QThread(parent), d(new CameraControllerPriv)
 {
     d->parent = parent;
 
@@ -149,6 +149,7 @@ CameraController::CameraController(QWidget* parent,
         KUrl url(path);
         kDebug() << "path " << path << " " << url <<  " " << url.host();
         QString xport = url.host();
+
         if (xport.startsWith(QLatin1String("usb:")))
         {
             kDebug() << "xport " << xport;
@@ -169,9 +170,13 @@ CameraController::CameraController(QWidget* parent,
     if (!d->camera)
     {
         if (model.toLower() == "directory browse")
+        {
             d->camera = new UMSCamera(title, model, port, path);
+        }
         else
+        {
             d->camera = new GPCamera(title, model, port, path);
+        }
     }
 
     // setup inter-thread signals
@@ -225,79 +230,130 @@ CameraController::~CameraController()
 
 bool CameraController::cameraThumbnailSupport()
 {
-    if (!d->camera) return false;
+    if (!d->camera)
+    {
+        return false;
+    }
+
     return d->camera->thumbnailSupport();
 }
 
 bool CameraController::cameraDeleteSupport()
 {
-    if (!d->camera) return false;
+    if (!d->camera)
+    {
+        return false;
+    }
+
     return d->camera->deleteSupport();
 }
 
 bool CameraController::cameraUploadSupport()
 {
-    if (!d->camera) return false;
+    if (!d->camera)
+    {
+        return false;
+    }
+
     return d->camera->uploadSupport();
 }
 
 bool CameraController::cameraMkDirSupport()
 {
-    if (!d->camera) return false;
+    if (!d->camera)
+    {
+        return false;
+    }
+
     return d->camera->mkDirSupport();
 }
 
 bool CameraController::cameraDelDirSupport()
 {
-    if (!d->camera) return false;
+    if (!d->camera)
+    {
+        return false;
+    }
+
     return d->camera->delDirSupport();
 }
 
 bool CameraController::cameraCaptureImageSupport()
 {
-    if (!d->camera) return false;
+    if (!d->camera)
+    {
+        return false;
+    }
+
     return d->camera->captureImageSupport();
 }
 
 QString CameraController::cameraPath()
 {
-    if (!d->camera) return QString();
+    if (!d->camera)
+    {
+        return QString();
+    }
+
     return d->camera->path();
 }
 
 QString CameraController::cameraTitle()
 {
-    if (!d->camera) return QString();
+    if (!d->camera)
+    {
+        return QString();
+    }
+
     return d->camera->title();
 }
 
 DKCamera::CameraDriverType CameraController::cameraDriverType()
 {
-    if (!d->camera) return DKCamera::UMSDriver;
+    if (!d->camera)
+    {
+        return DKCamera::UMSDriver;
+    }
+
     return d->camera->cameraDriverType();
 }
 
 QByteArray CameraController::cameraMD5ID()
 {
-    if (!d->camera) return QByteArray();
+    if (!d->camera)
+    {
+        return QByteArray();
+    }
+
     return d->camera->cameraMD5ID();
 }
 
 QPixmap CameraController::mimeTypeThumbnail(const QString& itemName)
 {
-    if (!d->camera) return QPixmap();
+    if (!d->camera)
+    {
+        return QPixmap();
+    }
 
     QFileInfo fi(itemName);
     QString mime = d->camera->mimeType(fi.suffix().toLower());
 
     if (mime.startsWith(QLatin1String("image/x-raw")))
+    {
         return DesktopIcon("kdcraw");
+    }
     else if (mime.startsWith(QLatin1String("image/")))
+    {
         return DesktopIcon("image-x-generic");
+    }
     else if (mime.startsWith(QLatin1String("video/")))
+    {
         return DesktopIcon("video-x-generic");
+    }
     else if (mime.startsWith(QLatin1String("audio/")))
+    {
         return DesktopIcon("audio-x-generic");
+    }
 
     return DesktopIcon("unknown");
 }
@@ -314,10 +370,11 @@ void CameraController::run()
 {
     while (d->running)
     {
-        CameraCommand *command;
+        CameraCommand* command;
 
         {
             QMutexLocker lock(&d->mutex);
+
             if (!d->commands.isEmpty())
             {
                 command = d->commands.takeFirst();
@@ -334,10 +391,11 @@ void CameraController::run()
         executeCommand(command);
         delete command;
     }
+
     sendBusy(false);
 }
 
-void CameraController::executeCommand(CameraCommand *cmd)
+void CameraController::executeCommand(CameraCommand* cmd)
 {
     switch (cmd->action)
     {
@@ -350,9 +408,13 @@ void CameraController::executeCommand(CameraCommand *cmd)
             emit signalConnected(result);
 
             if (result)
+            {
                 sendLogMsg(i18n("Connection established."));
+            }
             else
+            {
                 sendLogMsg(i18n("Connection failed."));
+            }
 
             break;
         }
@@ -414,6 +476,7 @@ void CameraController::executeCommand(CameraCommand *cmd)
             sendLogMsg(i18n("Listing files in %1...", folder));
 
             GPItemInfoList itemsList;
+
             if (!d->camera->getItemsInfoList(folder, itemsList, true))
             {
                 sendLogMsg(i18n("Failed to list files in %1.", folder), DHistoryView::ErrorEntry);
@@ -438,6 +501,7 @@ void CameraController::executeCommand(CameraCommand *cmd)
                 {
                     break;
                 }
+
                 QString folder = (*it).toStringList()[0];
                 QString file   = (*it).toStringList()[1];
 
@@ -454,6 +518,7 @@ void CameraController::executeCommand(CameraCommand *cmd)
                     emit signalThumbnailFailed(folder, file);
                 }
             }
+
             break;
         }
         case(CameraCommand::gp_exif):
@@ -483,6 +548,7 @@ void CameraController::executeCommand(CameraCommand *cmd)
                     emit signalExifData(ba);
                 }
             }
+
             break;
         }
         case(CameraCommand::gp_download):
@@ -540,9 +606,11 @@ void CameraController::executeCommand(CameraCommand *cmd)
                     }
 
                     TemplateManager* tm = TemplateManager::defaultManager();
+
                     if (tm && !templateTitle.isEmpty())
                     {
                         kDebug() << "Metadata template title : " << templateTitle;
+
                         if (templateTitle == Template::removeTemplateTitle())
                         {
                             metadata.removeMetadataTemplate();
@@ -558,6 +626,7 @@ void CameraController::executeCommand(CameraCommand *cmd)
                             metadata.setMetadataTemplate(tm->findByTitle(templateTitle));
                         }
                     }
+
                     metadata.applyChanges();
                 }
 
@@ -612,6 +681,7 @@ void CameraController::executeCommand(CameraCommand *cmd)
             {
                 sendLogMsg(i18n("Failed to retrieve file %1 from camera.", file), DHistoryView::ErrorEntry, folder, file);
             }
+
             break;
         }
         case(CameraCommand::gp_upload):
@@ -639,6 +709,7 @@ void CameraController::executeCommand(CameraCommand *cmd)
             {
                 emit signalInternalUploadFailed(folder, file, src);
             }
+
             break;
         }
         case(CameraCommand::gp_delete):
@@ -658,6 +729,7 @@ void CameraController::executeCommand(CameraCommand *cmd)
             {
                 emit signalInternalDeleteFailed(folder, file);
             }
+
             break;
         }
         case(CameraCommand::gp_lock):
@@ -678,6 +750,7 @@ void CameraController::executeCommand(CameraCommand *cmd)
             {
                 emit signalInternalLockFailed(folder, file);
             }
+
             break;
         }
         default:
@@ -696,7 +769,9 @@ void CameraController::sendLogMsg(const QString& msg, DHistoryView::EntryType ty
                                   const QString& folder, const QString& file)
 {
     if (!d->canceled)
+    {
         emit signalLogMsg(msg, type, folder, file);
+    }
 }
 
 void CameraController::slotCheckRename(const QString& folder, const QString& file,
@@ -712,6 +787,7 @@ void CameraController::slotCheckRename(const QString& folder, const QString& fil
     // Check if dest file already exist, unless we overwrite anyway
 
     QFileInfo info(dest);
+
     if (!d->overwriteAll)
     {
 
@@ -724,10 +800,10 @@ void CameraController::slotCheckRename(const QString& folder, const QString& fil
             }
 
             QPointer<KIO::RenameDialog> dlg = new KIO::RenameDialog(d->parent, i18n("Rename File"),
-                                                                    folder + QString("/") + file, dest,
-                                                                    KIO::RenameDialog_Mode(KIO::M_MULTI |
-                                                                    KIO::M_OVERWRITE                    |
-                                                                    KIO::M_SKIP));
+                    folder + QString("/") + file, dest,
+                    KIO::RenameDialog_Mode(KIO::M_MULTI |
+                                           KIO::M_OVERWRITE                    |
+                                           KIO::M_SKIP));
 
             int result = dlg->exec();
             dest       = dlg->newDestUrl().toLocalFile();
@@ -769,7 +845,9 @@ void CameraController::slotCheckRename(const QString& folder, const QString& fil
             }
 
             if (cancel || skip || overwrite)
+            {
                 break;
+            }
         }
     }
 
@@ -819,8 +897,11 @@ void CameraController::slotDownloadFailed(const QString& folder, const QString&
         {
             msg += i18n(" Do you want to continue?");
             int result = KMessageBox::warningContinueCancel(d->parent, msg);
+
             if (result != KMessageBox::Continue)
+            {
                 slotCancel();
+            }
         }
     }
 }
@@ -843,8 +924,11 @@ void CameraController::slotUploadFailed(const QString& folder, const QString& fi
         {
             msg += i18n(" Do you want to continue?");
             int result = KMessageBox::warningContinueCancel(d->parent, msg);
+
             if (result != KMessageBox::Continue)
+            {
                 slotCancel();
+            }
         }
     }
 }
@@ -866,8 +950,11 @@ void CameraController::slotDeleteFailed(const QString& folder, const QString& fi
         {
             msg += i18n(" Do you want to continue?");
             int result = KMessageBox::warningContinueCancel(d->parent, msg);
+
             if (result != KMessageBox::Continue)
+            {
                 slotCancel();
+            }
         }
     }
 }
@@ -889,8 +976,11 @@ void CameraController::slotLockFailed(const QString& folder, const QString& file
         {
             msg += i18n(" Do you want to continue?");
             int result = KMessageBox::warningContinueCancel(d->parent, msg);
+
             if (result != KMessageBox::Continue)
+            {
                 slotCancel();
+            }
         }
     }
 }
@@ -904,18 +994,22 @@ void CameraController::slotOpen(const QString& folder, const QString& file, cons
     KUrl::List urlList;
     urlList << url;
 
-    ImageWindow *im = ImageWindow::imagewindow();
+    ImageWindow* im = ImageWindow::imageWindow();
     im->loadURL(urlList, url, i18n("Camera \"%1\"",d->camera->model()), false);
 
     if (im->isHidden())
+    {
         im->show();
+    }
     else
+    {
         im->raise();
+    }
 
     im->setFocus();
 }
 
-void CameraController::addCommand(CameraCommand *cmd)
+void CameraController::addCommand(CameraCommand* cmd)
 {
     QMutexLocker lock(&d->mutex);
     d->commands << cmd;
@@ -931,7 +1025,7 @@ bool CameraController::queueIsEmpty()
 void CameraController::slotConnect()
 {
     d->canceled        = false;
-    CameraCommand *cmd = new CameraCommand;
+    CameraCommand* cmd = new CameraCommand;
     cmd->action        = CameraCommand::gp_connect;
     addCommand(cmd);
 }
@@ -939,7 +1033,7 @@ void CameraController::slotConnect()
 void CameraController::listFolders()
 {
     d->canceled        = false;
-    CameraCommand *cmd = new CameraCommand;
+    CameraCommand* cmd = new CameraCommand;
     cmd->action        = CameraCommand::gp_listfolders;
     addCommand(cmd);
 }
@@ -947,7 +1041,7 @@ void CameraController::listFolders()
 void CameraController::listFiles(const QString& folder)
 {
     d->canceled        = false;
-    CameraCommand *cmd = new CameraCommand;
+    CameraCommand* cmd = new CameraCommand;
     cmd->action        = CameraCommand::gp_listfiles;
     cmd->map.insert("folder", QVariant(folder));
     addCommand(cmd);
@@ -963,7 +1057,7 @@ void CameraController::getThumbnail(const QString& folder, const QString& file)
 void CameraController::getThumbnails(const QList<QVariant>& list)
 {
     d->canceled        = false;
-    CameraCommand *cmd = new CameraCommand;
+    CameraCommand* cmd = new CameraCommand;
     cmd->action        = CameraCommand::gp_thumbnails;
     cmd->map.insert("list", QVariant(list));
     addCommand(cmd);
@@ -972,7 +1066,7 @@ void CameraController::getThumbnails(const QList<QVariant>& list)
 void CameraController::getExif(const QString& folder, const QString& file)
 {
     d->canceled        = false;
-    CameraCommand *cmd = new CameraCommand;
+    CameraCommand* cmd = new CameraCommand;
     cmd->action        = CameraCommand::gp_exif;
     cmd->map.insert("folder", QVariant(folder));
     cmd->map.insert("file",   QVariant(file));
@@ -982,7 +1076,7 @@ void CameraController::getExif(const QString& folder, const QString& file)
 void CameraController::getCameraInformation()
 {
     d->canceled        = false;
-    CameraCommand *cmd = new CameraCommand;
+    CameraCommand* cmd = new CameraCommand;
     cmd->action        = CameraCommand::gp_cameraInformation;
     addCommand(cmd);
 }
@@ -990,7 +1084,7 @@ void CameraController::getCameraInformation()
 void CameraController::getFreeSpace()
 {
     d->canceled        = false;
-    CameraCommand *cmd = new CameraCommand;
+    CameraCommand* cmd = new CameraCommand;
     cmd->action        = CameraCommand::gp_freeSpace;
     addCommand(cmd);
 }
@@ -998,7 +1092,7 @@ void CameraController::getFreeSpace()
 void CameraController::getPreview()
 {
     d->canceled        = false;
-    CameraCommand *cmd = new CameraCommand;
+    CameraCommand* cmd = new CameraCommand;
     cmd->action        = CameraCommand::gp_preview;
     addCommand(cmd);
 }
@@ -1006,7 +1100,7 @@ void CameraController::getPreview()
 void CameraController::capture()
 {
     d->canceled        = false;
-    CameraCommand *cmd = new CameraCommand;
+    CameraCommand* cmd = new CameraCommand;
     cmd->action        = CameraCommand::gp_capture;
     addCommand(cmd);
 }
@@ -1014,7 +1108,7 @@ void CameraController::capture()
 void CameraController::upload(const QFileInfo& srcFileInfo, const QString& destFile, const QString& destFolder)
 {
     d->canceled        = false;
-    CameraCommand *cmd = new CameraCommand;
+    CameraCommand* cmd = new CameraCommand;
     cmd->action        = CameraCommand::gp_upload;
     cmd->map.insert("srcFilePath", QVariant(srcFileInfo.filePath()));
     cmd->map.insert("destFile",    QVariant(destFile));
@@ -1034,7 +1128,7 @@ void CameraController::downloadPrep()
 void CameraController::download(const DownloadSettingsContainer& downloadSettings)
 {
     d->canceled        = false;
-    CameraCommand *cmd = new CameraCommand;
+    CameraCommand* cmd = new CameraCommand;
     cmd->action        = CameraCommand::gp_download;
     cmd->map.insert("folder",            QVariant(downloadSettings.folder));
     cmd->map.insert("file",              QVariant(downloadSettings.file));
@@ -1051,7 +1145,7 @@ void CameraController::download(const DownloadSettingsContainer& downloadSetting
 void CameraController::deleteFile(const QString& folder, const QString& file)
 {
     d->canceled        = false;
-    CameraCommand *cmd = new CameraCommand;
+    CameraCommand* cmd = new CameraCommand;
     cmd->action        = CameraCommand::gp_delete;
     cmd->map.insert("folder", QVariant(folder));
     cmd->map.insert("file",   QVariant(file));
@@ -1061,7 +1155,7 @@ void CameraController::deleteFile(const QString& folder, const QString& file)
 void CameraController::lockFile(const QString& folder, const QString& file, bool locked)
 {
     d->canceled        = false;
-    CameraCommand *cmd = new CameraCommand;
+    CameraCommand* cmd = new CameraCommand;
     cmd->action        = CameraCommand::gp_lock;
     cmd->map.insert("folder", QVariant(folder));
     cmd->map.insert("file",   QVariant(file));
@@ -1072,7 +1166,7 @@ void CameraController::lockFile(const QString& folder, const QString& file, bool
 void CameraController::openFile(const QString& folder, const QString& file)
 {
     d->canceled        = false;
-    CameraCommand *cmd = new CameraCommand;
+    CameraCommand* cmd = new CameraCommand;
     cmd->action        = CameraCommand::gp_open;
     cmd->map.insert("folder", QVariant(folder));
     cmd->map.insert("file",   QVariant(file));
