@@ -52,23 +52,25 @@
 namespace Digikam
 {
 
-class ImageRegionWidgetPriv
+class ImageRegionWidget::ImageRegionWidgetPriv
 {
 
 public:
 
-    ImageRegionWidgetPriv()
+    ImageRegionWidgetPriv() :
+        onMouseMovePreviewToggled(true),
+        capturePtMode(false),
+        renderingPreviewMode(PreviewToolBar::PreviewBothImagesVertCont),
+        oldRenderingPreviewMode(PreviewToolBar::PreviewBothImagesVertCont),
+        xpos(0),
+        ypos(0),
+        iface(0)
     {
-        capturePtMode             = false;
-        onMouseMovePreviewToggled = true;
-        iface                     = 0;
-        renderingPreviewMode      = PreviewToolBar::PreviewBothImagesVertCont;
-        oldRenderingPreviewMode   = PreviewToolBar::PreviewBothImagesVertCont;
     }
 
     bool        onMouseMovePreviewToggled;
     bool        capturePtMode;
-    
+
     int         renderingPreviewMode;
     int         oldRenderingPreviewMode;
     int         xpos;
@@ -84,7 +86,7 @@ public:
 };
 
 ImageRegionWidget::ImageRegionWidget(QWidget* parent)
-                 : PreviewWidget(parent), d(new ImageRegionWidgetPriv)
+    : PreviewWidget(parent), d(new ImageRegionWidgetPriv)
 {
     d->iface = new ImageIface(0, 0);
     d->image = d->iface->getOriginalImg()->copy();
@@ -109,7 +111,11 @@ ImageRegionWidget::ImageRegionWidget(QWidget* parent)
 
 ImageRegionWidget::~ImageRegionWidget()
 {
-    if (d->iface) delete d->iface;
+    if (d->iface)
+    {
+        delete d->iface;
+    }
+
     delete d;
 }
 
@@ -152,6 +158,7 @@ void ImageRegionWidget::setCapturePointMode(bool b)
 {
     d->capturePtMode = b;
     viewport()->setMouseTracking(b);
+
     if (b)
     {
         d->oldRenderingPreviewMode = d->renderingPreviewMode;
@@ -169,7 +176,7 @@ bool ImageRegionWidget::capturePointMode()
 {
     return d->capturePtMode;
 }
-    
+
 void ImageRegionWidget::slotZoomFactorChanged()
 {
     emit signalContentsMovedEvent(true);
@@ -189,7 +196,7 @@ void ImageRegionWidget::viewportPaintExtraData()
         QPainter p(viewport());
         p.setRenderHint(QPainter::Antialiasing, true);
         p.setBackgroundMode(Qt::TransparentMode);
-         
+
         QRect region;
 
         // Original region.
@@ -198,7 +205,7 @@ void ImageRegionWidget::viewportPaintExtraData()
 
         // Target region.
         QRect rt(contentsToViewport(region.topLeft()), contentsToViewport(region.bottomRight()));
-        
+
         p.translate(previewRect().topLeft());
 
         // Drawing separate view.
@@ -206,7 +213,7 @@ void ImageRegionWidget::viewportPaintExtraData()
         if (d->renderingPreviewMode == PreviewToolBar::PreviewOriginalImage ||
             (d->renderingPreviewMode == PreviewToolBar::PreviewToggleOnMouseOver && !d->onMouseMovePreviewToggled))
         {
-           drawText(&p,QPoint(rt.topLeft().x()+20, rt.topLeft().y()+20),i18n("Original"));
+            drawText(&p,QPoint(rt.topLeft().x()+20, rt.topLeft().y()+20),i18n("Before"));
         }
         else if (d->renderingPreviewMode == PreviewToolBar::PreviewTargetImage ||
                  d->renderingPreviewMode == PreviewToolBar::NoPreviewMode      ||
@@ -217,17 +224,21 @@ void ImageRegionWidget::viewportPaintExtraData()
             if (d->renderingPreviewMode == PreviewToolBar::PreviewTargetImage ||
                 d->renderingPreviewMode == PreviewToolBar::PreviewToggleOnMouseOver)
             {
-                drawText(&p,QPoint(rt.topLeft().x()+20, rt.topLeft().y()+20),i18n("Target"));
+                drawText(&p,QPoint(rt.topLeft().x()+20, rt.topLeft().y()+20),i18n("After"));
             }
         }
         else if (d->renderingPreviewMode == PreviewToolBar::PreviewBothImagesVert ||
                  d->renderingPreviewMode == PreviewToolBar::PreviewBothImagesVertCont)
         {
             if (d->renderingPreviewMode == PreviewToolBar::PreviewBothImagesVert)
+            {
                 rt.translate(rt.width(), 0);
+            }
 
             if (d->renderingPreviewMode == PreviewToolBar::PreviewBothImagesVertCont)
+            {
                 ro.translate(-ro.width(), 0);
+            }
 
             p.drawPixmap(rt.x(), rt.y(), d->pixmapRegion, 0, 0, rt.width(), rt.height());
 
@@ -236,17 +247,21 @@ void ImageRegionWidget::viewportPaintExtraData()
             p.setPen(QPen(Qt::red, 2, Qt::DotLine));
             p.drawLine(rt.topLeft().x(), rt.topLeft().y()+1, rt.bottomLeft().x(), rt.bottomLeft().y()-1);
 
-            drawText(&p,QPoint(rt.topLeft().x()+20, rt.topLeft().y()+20),i18n("Target"));        
-            drawText(&p,QPoint(ro.topLeft().x()+20, ro.topLeft().y()+20),i18n("Original"));
+            drawText(&p,QPoint(ro.topLeft().x()+20, ro.topLeft().y()+20),i18n("Before"));
+            drawText(&p,QPoint(rt.topLeft().x()+20, rt.topLeft().y()+20),i18n("After"));
         }
         else if (d->renderingPreviewMode == PreviewToolBar::PreviewBothImagesHorz ||
                  d->renderingPreviewMode == PreviewToolBar::PreviewBothImagesHorzCont)
         {
             if (d->renderingPreviewMode == PreviewToolBar::PreviewBothImagesHorz)
+            {
                 rt.translate(0, rt.height());
+            }
 
             if (d->renderingPreviewMode == PreviewToolBar::PreviewBothImagesHorzCont)
+            {
                 ro.translate(0, -ro.height());
+            }
 
             p.drawPixmap(rt.x(), rt.y(), d->pixmapRegion, 0, 0, rt.width(), rt.height());
 
@@ -255,8 +270,8 @@ void ImageRegionWidget::viewportPaintExtraData()
             p.setPen(QPen(Qt::red, 2, Qt::DotLine));
             p.drawLine(rt.topLeft().x()  , rt.topLeft().y(), rt.topRight().x()  , rt.topRight().y());
 
-            drawText(&p,QPoint(rt.topLeft().x()+20, rt.topLeft().y()+20),i18n("Target")); 
-            drawText(&p,QPoint(ro.topLeft().x()+20, ro.topLeft().y()+20),i18n("Original"));
+            drawText(&p,QPoint(ro.topLeft().x()+20, ro.topLeft().y()+20),i18n("Before"));
+            drawText(&p,QPoint(rt.topLeft().x()+20, rt.topLeft().y()+20),i18n("After"));
         }
 
         // Drawing highlighted points.
@@ -391,13 +406,17 @@ void ImageRegionWidget::setCenterImageRegionPosition()
 
 void ImageRegionWidget::setContentsPosition(int x, int y, bool targetDone)
 {
-    if( targetDone )
+    if ( targetDone )
+    {
         m_movingInProgress = false;
+    }
 
     setContentsPos(x, y);
 
-    if( targetDone )
-       slotZoomFactorChanged();
+    if ( targetDone )
+    {
+        slotZoomFactorChanged();
+    }
 }
 
 void ImageRegionWidget::backupPixmapRegion()
@@ -422,20 +441,24 @@ void ImageRegionWidget::setPreviewImage(const DImg& img)
     // restore the embedded ICC color profile.
     // However, some plugins may set a profile on the preview image, which we accept of course.
     if (image.getIccProfile().isNull())
+    {
         image.setIccProfile(d->image.getIccProfile());
+    }
 
     d->pixmapRegion = d->iface->convertToPixmap(image);
     repaintContents(false);
 }
 
-DImg ImageRegionWidget::getOriginalRegionImage(bool use_downscaled_image)
+DImg ImageRegionWidget::getOriginalRegionImage(bool useDownscaledImage)
 {
     DImg image = d->image.copy(getOriginalImageRegionToRender());
-    if (use_downscaled_image)
-     {
-      QRect r = getLocalImageRegionToRender();
-      image.resize(r.width(), r.height());
-     }
+
+    if (useDownscaledImage)
+    {
+        QRect r = getLocalImageRegionToRender();
+        image.resize(r.width(), r.height());
+    }
+
     return (image);
 }
 
@@ -522,33 +545,47 @@ void ImageRegionWidget::contentsMousePressEvent(QMouseEvent* e)
             (d->renderingPreviewMode == PreviewToolBar::PreviewToggleOnMouseOver && !d->onMouseMovePreviewToggled))
         {
             if (ro.contains(pt))
+            {
                 emitCapturedPointFromOriginal(pt - ro.topLeft());
+            }
         }
         else if (d->renderingPreviewMode == PreviewToolBar::PreviewBothImagesVert ||
-                d->renderingPreviewMode == PreviewToolBar::PreviewBothImagesVertCont)
+                 d->renderingPreviewMode == PreviewToolBar::PreviewBothImagesVertCont)
         {
             if (d->renderingPreviewMode == PreviewToolBar::PreviewBothImagesVert)
+            {
                 rt.translate(rt.width(), 0);
+            }
 
             if (d->renderingPreviewMode == PreviewToolBar::PreviewBothImagesVertCont)
+            {
                 ro.translate(-ro.width(), 0);
+            }
 
             if (!rt.contains(pt) && ro.contains(pt))
+            {
                 emitCapturedPointFromOriginal(pt - ro.topLeft());
+            }
         }
         else if (d->renderingPreviewMode == PreviewToolBar::PreviewBothImagesHorz ||
-                d->renderingPreviewMode == PreviewToolBar::PreviewBothImagesHorzCont)
+                 d->renderingPreviewMode == PreviewToolBar::PreviewBothImagesHorzCont)
         {
             if (d->renderingPreviewMode == PreviewToolBar::PreviewBothImagesHorz)
+            {
                 rt.translate(0, rt.height());
+            }
 
             if (d->renderingPreviewMode == PreviewToolBar::PreviewBothImagesHorzCont)
+            {
                 ro.translate(0, -ro.height());
+            }
 
             if (!rt.contains(pt) && ro.contains(pt))
+            {
                 emitCapturedPointFromOriginal(pt - ro.topLeft());
-        }        
-        
+            }
+        }
+
         return;
     }
 
